@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                          QIcon(":/images/button-password.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
-    this->setMinimumSize(640, 380);
+    this->setMinimumSize(640, 480);
 
     this->pController = pumpController;
 
@@ -39,50 +39,84 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     QFont helpFont;
     helpFont.setPointSize(helpFont.pointSize() - 1);
 
-    this->helpMessage1Label = new QLabel(tr("First, enter your Webfinger ID, your pump.io address.") + "\n"
-                                         + tr("Your address looks like username@pumpserver.org, and "
-                                              "you can find it in your profile, in the web interface.") + "\n"
-                                         + tr("If your profile is at https://pump.example/yourname, then "
-                                              "your address is yourname@pump.example"));
+    this->helpMessage1Label = new QLabel(tr("First, enter your Webfinger ID, "
+                                            "your pump.io address.") + "<br>"
+                                         + tr("Your address looks like "
+                                              "username@pumpserver.org, and "
+                                              "you can find it in your profile, "
+                                              "in the web interface.") + "<br>"
+                                         + tr("If your profile is at "
+                                              "https://pump.example/yourname, then "
+                                              "your address is yourname@pump.example")
+                                         + "<br><br>"
+                                         + tr("If you don't have an account yet, "
+                                              "you can sign up for one at %1. "
+                                              "This link will take you to a "
+                                              "random public server.",
+                                              "1=link to website")
+                                           .arg("<a href=\"http://pump.io/tryit.html\">"
+                                                "pump.io/tryit.html</a>")
+                                         + "<br><br>"
+                                         + tr("If you need help: %1")
+                                           .arg("<a href=\"https://github.com/"
+                                                "e14n/pump.io/wiki/User-Guide\">"
+                                                + tr("Pump.io User Guide")
+                                                + "</a>"),
+                                         this);
     helpMessage1Label->setWordWrap(true);
     helpMessage1Label->setFont(helpFont);
+    helpMessage1Label->setOpenExternalLinks(true);
 
-    userIDIconLabel = new QLabel();
+    userIDIconLabel = new QLabel(this);
     userIDIconLabel->setPixmap(QIcon::fromTheme("preferences-desktop-user",
-                                                QIcon(":/images/no-avatar.png")).pixmap(32,32));
-    userIDLabel = new QLabel(tr("Your Pump.io address:"));
-    userIDLineEdit = new QLineEdit();
-    userIDLineEdit->setPlaceholderText(tr("Webfinger ID, like username@pumpserver.org"));
-    userIDLineEdit->setToolTip(tr("Your address, as username@server"));
+                                                QIcon(":/images/no-avatar.png"))
+                               .pixmap(64,64)
+                               .scaledToWidth(64, Qt::SmoothTransformation));
+    userIDLabel = new QLabel(tr("Your Pump.io address:"), this);
+    userIDLineEdit = new QLineEdit(this);
+    QString userIdTooltip = tr("Your address, like username@pumpserver.org");
+    userIDLineEdit->setPlaceholderText(userIdTooltip);
+    userIDLineEdit->setToolTip("<b></b>" + userIdTooltip); // HTMLized for wordwrap
 
     getVerifierButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
-                                        tr("Get &Verifier Code"));
-    getVerifierButton->setToolTip(tr("After clicking this button, a web browser will "
-                                     "open, requesting authorization for Dianara"));
+                                        tr("Get &Verifier Code"), this);
+    getVerifierButton->setToolTip("<b></b>" +
+                                  tr("After clicking this button, a web "
+                                     "browser will open, requesting "
+                                     "authorization for Dianara"));
     connect(getVerifierButton, SIGNAL(clicked()),
             this, SLOT(askForToken()));
 
 
-    this->helpMessage2Label = new QLabel(tr("Once you have authorized Dianara from your Pump server "
-                                            "web interface, you'll receive a code called VERIFIER.\n"
-                                            "Copy it and paste it into the field below.",
-                                            // Comment for the translators
-                                            "Don't translate the VERIFIER word!"));
+    this->helpMessage2Label = new QLabel(tr("Once you have authorized Dianara "
+                                            "from your Pump server web "
+                                            "interface, you'll receive a code "
+                                            "called VERIFIER.\n"
+                                            "Copy it and paste it into the "
+                                            "field below.",
+                                            // Comment for translators
+                                            "Don't translate the VERIFIER word!"),
+                                         this);
     helpMessage2Label->setWordWrap(true);
     helpMessage2Label->setFont(helpFont);
 
 
-    verifierIconLabel = new QLabel();
+    verifierIconLabel = new QLabel(this);
     verifierIconLabel->setPixmap(QIcon::fromTheme("dialog-password",
-                                                  QIcon(":/images/button-password.png")).pixmap(32,32));
-    verifierLabel = new QLabel(tr("Verifier code:"));
-    verifierLineEdit = new QLineEdit();
-    verifierLineEdit->setPlaceholderText(tr("Enter the verifier code provided by your Pump server here"));
-    verifierLineEdit->setToolTip(tr("Paste the verifier here"));
+                                                  QIcon(":/images/button-password.png"))
+                                 .pixmap(64,64)
+                                 .scaledToWidth(64, Qt::SmoothTransformation));
+    verifierLabel = new QLabel(tr("Verifier code:"), this);
+    verifierLineEdit = new QLineEdit(this);
+    QString verifierTooltip = tr("Enter or paste the verifier code provided "
+                                 "by your Pump server here");
+    verifierLineEdit->setPlaceholderText(verifierTooltip);
+    verifierLineEdit->setToolTip("<b></b>" + verifierTooltip);
 
 
     authorizeApplicationButton = new QPushButton(QIcon::fromTheme("security-high"),
-                                                 tr("&Authorize Application"));
+                                                 tr("&Authorize Application"),
+                                                 this);
     connect(authorizeApplicationButton, SIGNAL(clicked()),
             this, SLOT(setVerifierCode()));
 
@@ -90,7 +124,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
 
     // To notify invalid ID or empty verifier code
     // Cleared when typing in any of the two fields
-    errorsLabel = new QLabel();
+    errorsLabel = new QLabel(this);
     errorsLabel->setOpenExternalLinks(true);
     connect(userIDLineEdit, SIGNAL(textChanged(QString)),
             errorsLabel, SLOT(clear()));
@@ -102,39 +136,52 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     authorizationStatusFont.setPointSize(authorizationStatusFont.pointSize() + 2);
     authorizationStatusFont.setBold(true);
 
-    authorizationStatusLabel = new QLabel();
+    authorizationStatusLabel = new QLabel(this);
     authorizationStatusLabel->setFont(authorizationStatusFont);
 
 
     saveButton = new QPushButton(QIcon::fromTheme("document-save",
                                                   QIcon(":/images/button-save.png")),
-                                 tr("&Save Details"));
+                                 tr("&Save Details"),
+                                 this);
+    saveButton->setDisabled(true); // Disabled initially
     connect(saveButton, SIGNAL(clicked()),
             this, SLOT(saveDetails()));
+
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
-                                   tr("&Cancel"));
+                                   tr("&Cancel"),
+                                   this);
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(hide()));
 
 
-    // Layout
-    this->mainLayout = new QVBoxLayout();
-    mainLayout->addWidget(helpMessage1Label, 3);
-    mainLayout->addStretch(2);
+    // Unlock button, visible when the account is already authorized, + info
+    this->unlockExplanationLabel = new QLabel("<b>"
+                                              + tr("Your account is properly "
+                                                   "configured.")
+                                              + "</b>"
+                                                "<br><br>"
+                                              + tr("Press Unlock if you wish "
+                                                   "to configure a different "
+                                                   "account.")
+                                              + "<hr>",
+                                              this);
+    unlockExplanationLabel->setAlignment(Qt::AlignHCenter);
 
+    this->unlockButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
+                                         tr("&Unlock"), this);
+    connect(unlockButton, SIGNAL(clicked()),
+            this, SLOT(unlockDialog()));
+
+
+    //////////////////////////////////////////////////////////////////// Layout
     this->idLayout = new QHBoxLayout();
     idLayout->addWidget(userIDIconLabel);
     idLayout->addSpacing(4);
     idLayout->addWidget(userIDLabel);
     idLayout->addWidget(userIDLineEdit);
     idLayout->addWidget(getVerifierButton);
-    mainLayout->addLayout(idLayout, 3);
-    mainLayout->addStretch(3);
-    mainLayout->addSpacing(12);
-
-    mainLayout->addWidget(helpMessage2Label, 3);
-    mainLayout->addStretch(2);
 
     this->verifierLayout = new QHBoxLayout();
     verifierLayout->addWidget(verifierIconLabel);
@@ -142,27 +189,42 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     verifierLayout->addWidget(verifierLabel);
     verifierLayout->addWidget(verifierLineEdit);
     verifierLayout->addWidget(authorizeApplicationButton);
-    mainLayout->addLayout(verifierLayout, 3);
 
-    mainLayout->addWidget(errorsLabel,              1, Qt::AlignCenter);
-    mainLayout->addSpacing(4);
-    mainLayout->addWidget(authorizationStatusLabel, 1, Qt::AlignCenter);
-    mainLayout->addStretch(2);
-    mainLayout->addSpacing(16);
 
     this->buttonsLayout = new QHBoxLayout();
     buttonsLayout->setAlignment(Qt::AlignRight);
     buttonsLayout->addWidget(saveButton);
     buttonsLayout->addWidget(cancelButton);
-    mainLayout->addLayout(buttonsLayout, 1);
 
+
+    this->mainLayout = new QVBoxLayout();
+    mainLayout->addWidget(unlockExplanationLabel, 6);
+    mainLayout->addWidget(unlockButton, 0, Qt::AlignHCenter);
+
+    mainLayout->addWidget(helpMessage1Label, 6);
+    mainLayout->addSpacing(8);
+    mainLayout->addStretch(1);
+    mainLayout->addLayout(idLayout, 2);
+    mainLayout->addStretch(1);
+    mainLayout->addSpacing(16);
+    mainLayout->addWidget(helpMessage2Label, 2);
+    mainLayout->addSpacing(8);
+    mainLayout->addStretch(1);
+    mainLayout->addLayout(verifierLayout, 2);
+    mainLayout->addWidget(errorsLabel,              1, Qt::AlignCenter);
+    mainLayout->addSpacing(4);
+    mainLayout->addWidget(authorizationStatusLabel, 1, Qt::AlignCenter);
+    mainLayout->addStretch(1);
+    mainLayout->addSpacing(8);
+    mainLayout->addLayout(buttonsLayout, 1);
     this->setLayout(mainLayout);
 
 
     QSettings settings;  // Load saved User ID
-    userIDLineEdit->setText(settings.value("userID", "").toString());
+    userIDLineEdit->setText(settings.value("userID").toString());
 
-    this->showAuthorizationStatus(settings.value("isApplicationAuthorized", false).toBool());
+    this->showAuthorizationStatus(settings.value("isApplicationAuthorized",
+                                                 false).toBool());
 
 
     // Disable verifier input field and button initially
@@ -181,10 +243,37 @@ AccountDialog::~AccountDialog()
 }
 
 
+void AccountDialog::setLockMode(bool locked)
+{
+    if (locked)
+    {
+        this->helpMessage1Label->hide();
+        this->helpMessage2Label->hide();
 
-//////////////////////////////////////////////////////////////////////
-///////////////////////////////// SLOTS //////////////////////////////
-//////////////////////////////////////////////////////////////////////
+        this->unlockExplanationLabel->show();
+        this->unlockButton->show();
+
+        this->verifierLineEdit->setDisabled(true);
+        this->authorizeApplicationButton->setDisabled(true);
+    }
+    else
+    {
+        this->helpMessage1Label->show();
+        this->helpMessage2Label->show();
+
+        this->unlockExplanationLabel->hide();
+        this->unlockButton->hide();
+    }
+
+    this->userIDLineEdit->setDisabled(locked);
+    this->getVerifierButton->setDisabled(locked);
+}
+
+
+
+//////////////////////////////////////////////////////////////////////////////
+///////////////////////////////////// SLOTS //////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
 
 
 
@@ -232,6 +321,7 @@ void AccountDialog::setVerifierCode()
     if (!this->verifierLineEdit->text().trimmed().isEmpty())
     {
         this->pController->authorizeApplication(this->verifierLineEdit->text().trimmed());
+        this->saveButton->setEnabled(true);
     }
     else
     {
@@ -254,6 +344,8 @@ void AccountDialog::showAuthorizationStatus(bool authorized)
     {
         this->authorizationStatusLabel->clear();
     }
+
+    this->setLockMode(this->pController->currentlyAuthorized());
 }
 
 
@@ -292,11 +384,38 @@ void AccountDialog::saveDetails()
 
     QSettings settings;
     settings.setValue("userID", newUserID);
+    settings.sync();
 
     emit userIDChanged(newUserID);
 
 
     this->errorsLabel->clear(); // Clear previous error messages, if any
 
+    // If it's authorized, disable the Save Details button
+    if (this->pController->currentlyAuthorized())
+    {
+        this->saveButton->setDisabled(true);
+    }
+
     this->hide(); // close() would end program if main window was hidden
 }
+
+
+void AccountDialog::unlockDialog()
+{
+    this->setLockMode(false);
+}
+
+
+
+//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////// PROTECTED ////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
+void AccountDialog::hideEvent(QHideEvent *event)
+{
+    this->setLockMode(this->pController->currentlyAuthorized());
+
+    event->accept();
+}
