@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -36,13 +36,30 @@ ASPerson::ASPerson(QVariantMap personMap,
     this->updatedAt = personMap.value("updated").toString();
 
 
-    qDebug() << "ASPerson created" << this->id;
+    //qDebug() << "ASPerson created" << this->id;
 }
 
 
 ASPerson::~ASPerson()
 {
-    qDebug() << "ASPerson destroyed" << this->id;
+    //qDebug() << "ASPerson destroyed" << this->id;
+}
+
+
+
+void ASPerson::updateDataFromPerson(ASPerson *person)
+{
+    this->id = person->getId();
+    this->name = person->getNameWithFallback();
+    this->avatar = person->getAvatar();
+    this->url = person->getUrl();
+    this->hometown = person->getHometown();
+    this->bio = person->getBio();
+
+    this->followed = person->isFollowed() ? "true" : "false";
+
+    this->createdAt = person->getCreatedAt();
+    this->updatedAt = person->getupdatedAt();
 }
 
 
