@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -56,18 +56,20 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     // Left side, all contacts, with filter
     this->peopleWidget = new PeopleWidget(tr("&Add to Selected") + " >>",
                                           PeopleWidget::EmbeddedWidget,
-                                          pumpController);
-    connect(peopleWidget, SIGNAL(contactSelected(QIcon,QString)),
-            this, SLOT(copyToSelected(QIcon,QString)));
-    connect(peopleWidget, SIGNAL(addButtonPressed(QIcon,QString)),
-            this, SLOT(copyToSelected(QIcon,QString)));
+                                          pumpController,
+                                          this);
+    connect(peopleWidget, SIGNAL(contactSelected(QIcon,QString,QString)),
+            this, SLOT(copyToSelected(QIcon,QString,QString)));
+    connect(peopleWidget, SIGNAL(addButtonPressed(QIcon,QString,QString)),
+            this, SLOT(copyToSelected(QIcon,QString,QString)));
 
 
 
     this->allGroupboxLayout = new QVBoxLayout();
     allGroupboxLayout->addWidget(peopleWidget);
 
-    allContactsGroupbox = new QGroupBox(tr("All Contacts"));
+    allContactsGroupbox = new QGroupBox(tr("All Contacts"),
+                                        this);
     allContactsGroupbox->setLayout(allGroupboxLayout);
 
 
@@ -75,10 +77,11 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     explanationLabel = new QLabel(tr("Select people from the list on the left.\n"
                                      "You can drag them with the mouse, click or "
                                      "double-click on them, or select them and "
-                                     "use the button below."));
+                                     "use the button below."),
+                                  this);
     explanationLabel->setWordWrap(true);
 
-    selectedListWidget = new QListWidget();
+    selectedListWidget = new QListWidget(this);
     selectedListWidget->setDragDropMode(QListView::DragDrop);
     selectedListWidget->setDefaultDropAction(Qt::MoveAction);
     selectedListWidget->setSelectionMode(QListView::ExtendedSelection);
@@ -86,18 +89,22 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
 
     this->clearSelectedListButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
                                                                      QIcon(":/images/button-delete.png")),
-                                                    tr("Clear &List"));
+                                                    tr("Clear &List"),
+                                                    this);
     connect(clearSelectedListButton, SIGNAL(clicked()),
             selectedListWidget, SLOT(clear()));
 
 
-    doneButton = new QPushButton(QIcon::fromTheme("dialog-ok"),
-                                 tr("&Done"));
+    doneButton = new QPushButton(QIcon::fromTheme("dialog-ok",
+                                                  QIcon(":/images/button-save.png")),
+                                 tr("&Done"),
+                                 this);
     connect(doneButton, SIGNAL(clicked()),
             this, SLOT(setAudience()));
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
-                                   tr("&Cancel"));
+                                   tr("&Cancel"),
+                                   this);
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(close()));
 
@@ -116,7 +123,8 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     selectedGroupboxLayout->addSpacing(8);
     selectedGroupboxLayout->addLayout(buttonsLayout);
 
-    this->selectedListGroupbox = new QGroupBox(tr("Selected People"));
+    this->selectedListGroupbox = new QGroupBox(tr("Selected People"),
+                                               this);
     selectedListGroupbox->setLayout(selectedGroupboxLayout);
 
     this->mainLayout = new QHBoxLayout();
@@ -213,14 +221,26 @@ void AudienceSelector::restoreSelected()
  * The contact string comes in a SIGNAL from PeopleWidget
  *
  */
-void AudienceSelector::copyToSelected(QIcon contactIcon,
-                                      QString contactString)
+void AudienceSelector::copyToSelected(QIcon contactIcon, QString contactString,
+                                      QString contactUrl)
 {
     if (!contactString.isEmpty())
     {
-        QListWidgetItem *item = new QListWidgetItem(contactIcon,
-                                                    contactString);
-        this->selectedListWidget->addItem(item);
+        int itemExists = selectedListWidget->findItems(contactString,
+                                                       Qt::MatchExactly).size();
+        if (itemExists == 0)
+        {
+            QListWidgetItem *item = new QListWidgetItem(contactIcon,
+                                                        contactString);
+            item->setData(Qt::UserRole + 1, contactUrl);
+
+            this->selectedListWidget->addItem(item);
+        }
+        else
+        {
+            qDebug() << "AudienceSelector::copyToSelected() "
+                        "ignoring already added recipient";
+        }
     }
 }
 
@@ -232,17 +252,19 @@ void AudienceSelector::copyToSelected(QIcon contactIcon,
  */
 void AudienceSelector::setAudience()
 {
-    QStringList addressList;
-
     int addressCount = this->selectedListWidget->count();
 
+    QStringList addressList;
+    QStringList urlList;
     for (int counter=0; counter < addressCount; ++counter)
     {
         addressList.append(selectedListWidget->item(counter)->text());
+        urlList.append(selectedListWidget->item(counter)->data(Qt::UserRole + 1)
+                                                         .toString());
     }
 
 
-    emit audienceSelected(selectorType, addressList);
+    emit audienceSelected(selectorType, addressList, urlList);
 
     saveSelected();  // To restore the list later, if the dialog is shown again
 
@@ -268,7 +290,10 @@ void AudienceSelector::closeEvent(QCloseEvent *event)
 void AudienceSelector::hideEvent(QHideEvent *event)
 {
     QSettings settings;
-    settings.setValue("AudienceSelector/audienceWindowSize", this->size());
+    if (settings.isWritable())
+    {
+        settings.setValue("AudienceSelector/audienceWindowSize", this->size());
+    }
 
     event->accept();
 }
