@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -88,8 +88,10 @@ AvatarButton::~AvatarButton()
 void AvatarButton::setGenericAvatarIcon()
 {
     this->setIcon(QIcon::fromTheme("user-identity",
-                                   QIcon(":/images/no-avatar.png")));
-
+                                   QIcon(":/images/no-avatar.png"))
+                  .pixmap(this->iconSize())
+                  .scaledToWidth(this->iconWidth,
+                                 Qt::SmoothTransformation));
 }
 
 
@@ -274,7 +276,9 @@ void AvatarButton::unfollowUser()
 
 void AvatarButton::sendMessageToUser()
 {
-    this->globalObj->createMessageForContact(this->authorName, this->authorId);
+    this->globalObj->createMessageForContact(this->authorId,
+                                             this->authorName,
+                                             this->authorUrl);
 
 }
 
