@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -60,6 +60,7 @@ Comment::Comment(PumpController *pumpController,
         this->setFrameStyle(QFrame::Raised | QFrame::StyledPanel);
     }
 
+    this->commentIsDeleted = false;
 
 
     // Avatar pixmap
@@ -91,26 +92,12 @@ Comment::Comment(PumpController *pumpController,
 
 
     // Timestamps
-    createdAt = commentObject->getCreatedAt();
-    updatedAt = commentObject->getUpdatedAt();
-
     metadataFont.setBold(false);
     metadataFont.setItalic(true);
-
-    timestampLabel = new HClabel();
+    timestampLabel = new HClabel("", this);
     timestampLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
     timestampLabel->setWordWrap(false); // ON by default in HClabel
     timestampLabel->setFont(metadataFont);
-    QString timestampTooltip = tr("Posted on %1")
-                                .arg(Timestamp::localTimeDate(createdAt));
-    if (createdAt != updatedAt)
-    {
-        timestampTooltip.append("<br>"
-                                + tr("Modified on %1")
-                                   .arg(Timestamp::localTimeDate(updatedAt)));
-    }
-    timestampLabel->setToolTip(timestampTooltip); // Precise time on tooltip
-    this->setFuzzyTimestamps();
 
 
 
@@ -127,15 +114,6 @@ Comment::Comment(PumpController *pumpController,
     connect(likeLabel, SIGNAL(linkActivated(QString)),
             this, SLOT(likeComment(QString)));
 
-    if (commentObject->isLiked() == "true")
-    {
-        commentIsLiked = true;
-    }
-    else
-    {
-        commentIsLiked = false;
-    }
-    this->fixLikeLabelText();
 
 
     quoteLabel = new QLabel("<a href=\"quote://\">"
@@ -183,13 +161,8 @@ Comment::Comment(PumpController *pumpController,
     metadataFont.setBold(false);
     likesCountLabel->setFont(metadataFont);
 
-    this->setLikesCount(commentObject->getLikesCount(),
-                        commentObject->getLastLikesList());
-
-    // The comment itself
-    this->commentOriginalText = commentObject->getContent();
-
 
+    // Main content, the comment itself
     contentLabel = new QLabel(this);
     contentLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     contentLabel->setFont(commentsFont);
@@ -205,18 +178,19 @@ Comment::Comment(PumpController *pumpController,
             this, SLOT(showUrlInfo(QString)));
 
 
+    // This is used to draw a colored vertical line, as a hint
+    hintWidget = new QWidget(this);
+    hintWidget->hide();
 
-    pendingImagesList = MiscHelpers::htmlWithReplacedImages(commentOriginalText,
-                                                            64); // Arbitrary width
-    pendingImagesList.removeFirst(); // First one is the HTML with images replaced
-    this->getPendingImages();
 
 
     // Layout
     leftLayout = new QVBoxLayout();
+    leftLayout->setContentsMargins(0, 0, 0, 0);
     leftLayout->setAlignment(Qt::AlignLeft);
     leftLayout->addWidget(avatarButton,    0, Qt::AlignLeft | Qt::AlignTop);
-    leftLayout->addWidget(likesCountLabel, 1, Qt::AlignHCenter | Qt::AlignTop);
+    leftLayout->addWidget(likesCountLabel, 0, Qt::AlignHCenter | Qt::AlignTop);
+    leftLayout->addStretch();
 
     rightTopLayout = new QHBoxLayout();
     rightTopLayout->addWidget(fullNameLabel,  0, Qt::AlignLeft);
@@ -240,17 +214,18 @@ Comment::Comment(PumpController *pumpController,
     rightLayout->addLayout(rightTopLayout, 0);
     rightLayout->addSpacing(4); // 4px vertical space separation
     rightLayout->addWidget(contentLabel,   1, Qt::AlignTop);
-    rightLayout->addSpacing(2); // and 2px more as margin
+    rightLayout->addSpacing(1); // and 1px more as margin
 
 
     mainLayout = new QHBoxLayout();
+    mainLayout->setContentsMargins(2, 2, 2, 2);
+    mainLayout->addWidget(hintWidget);
     mainLayout->addLayout(leftLayout);
     mainLayout->addLayout(rightLayout);
     this->setLayout(mainLayout);
 
 
-    setCommentContents();
-
+    this->updateDataFromObject(commentObject);
 
     qDebug() << "Comment created" << this->commentId;
 }
@@ -262,6 +237,54 @@ Comment::~Comment()
 }
 
 
+/*
+ * Fill in or replace data such as timestamps, title, contents,
+ * number of likes and shares, etc, from object data
+ *
+ */
+void Comment::updateDataFromObject(ASObject *object)
+{
+    // Timestamps
+    this->createdAt = object->getCreatedAt();
+    this->updatedAt = object->getUpdatedAt();
+    QString timestampTooltip = tr("Posted on %1")
+                               .arg(Timestamp::localTimeDate(createdAt));
+    if (createdAt != updatedAt)
+    {
+        timestampTooltip.append("<br>"
+                                + tr("Modified on %1")
+                                  .arg(Timestamp::localTimeDate(updatedAt)));
+    }
+    timestampLabel->setToolTip(timestampTooltip); // Precise time on tooltip
+    this->setFuzzyTimestamps();
+
+
+    this->setLikesCount(object->getLikesCount(),
+                        object->getLastLikesList());
+
+    if (object->isLiked() == "true")
+    {
+        commentIsLiked = true;
+    }
+    else
+    {
+        commentIsLiked = false;
+    }
+    this->fixLikeLabelText();
+
+
+    // The comment itself
+    this->commentOriginalText = object->getContent();
+    pendingImagesList = MiscHelpers::htmlWithReplacedImages(commentOriginalText,
+                                                            128); // Arbitrary (initial) width
+    pendingImagesList.removeFirst(); // First one is the HTML with images replaced
+    this->getPendingImages();
+
+
+    this->setCommentContents();
+}
+
+
 
 void Comment::fixLikeLabelText()
 {
@@ -350,6 +373,15 @@ void Comment::setCommentContents()
 }
 
 
+void Comment::onResize()
+{
+    contentLabel->ensurePolished();
+    int height = contentLabel->heightForWidth(contentLabel->width());
+    this->contentLabel->setMinimumHeight(height);
+    this->contentLabel->setMaximumHeight(height);
+}
+
+
 
 void Comment::getPendingImages()
 {
@@ -366,6 +398,64 @@ void Comment::getPendingImages()
 }
 
 
+QString Comment::getObjectId()
+{
+    return this->commentId;
+}
+
+
+/*
+ * A thin line on left side as hint to indicate comment is yours
+ * or from the author of the parent post
+ *
+ */
+void Comment::setHint(QString color)
+{
+    if (color.isEmpty())
+    {
+        color = "palette(highlight)";
+    }
+
+    // Transparent to your color to transparent gradient
+    QString css = QString("QWidget "
+                          "{ background-color: "
+                          "  qlineargradient(spread:pad, "
+                          "  x1:0, y1:0, x2:1, y2:0, "
+                          "  stop:0 rgba(0, 0, 0, 0), "
+                          "  stop:0.25 %1, stop:0.75 %1, "
+                          "  stop:1 rgba(0, 0, 0, 0) ); "
+                          "}").arg(color);
+
+    this->hintWidget->setStyleSheet(css);
+    this->hintWidget->setFixedWidth(4); // 4 px
+    this->hintWidget->show();
+}
+
+
+void Comment::setCommentDeleted(QString deletedTime)
+{
+    if (commentIsDeleted)
+    {
+        return; // Was already deleted, so just ignore
+    }
+
+    this->commentIsDeleted = true;
+
+    if (!this->commentOriginalText.isEmpty())
+    {
+        this->commentOriginalText.prepend("<hr>"); // --------
+    }
+    this->commentOriginalText.prepend("<center>" + deletedTime +
+                                      "</center>");
+    qDebug() << "This comment was deleted on" << deletedTime;
+
+    this->setCommentContents();
+    this->onResize();
+
+    this->setDisabled(true);
+}
+
+
 
 /****************************************************************************/
 /******************************** SLOTS *************************************/
@@ -456,7 +546,8 @@ void Comment::deleteComment()
         qDebug() << "Deleting comment" << this->commentId;
         this->pController->deletePost(this->commentId, this->objectType);
 
-        this->setDisabled(true); // disable... maybe hide?
+        QString timeNow = QDateTime::currentDateTimeUtc().toString(Qt::ISODate);
+        this->setCommentDeleted(ASObject::makeDeletedOnString(timeNow));
     }
     else
     {
@@ -527,12 +618,10 @@ void Comment::leaveEvent(QEvent *event)
 
 void Comment::resizeEvent(QResizeEvent *event)
 {
-    qDebug() << "Comment::resizeEvent()"
-             << event->oldSize() << ">" << event->size();
+    //qDebug() << "Comment::resizeEvent()"
+    //         << event->oldSize() << ">" << event->size();
 
-    int height = contentLabel->heightForWidth(contentLabel->width());
-    this->contentLabel->setMinimumHeight(height);
-    this->contentLabel->setMaximumHeight(height);
+    this->onResize();
 
     event->accept();
 }
