@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,6 +53,8 @@ public:
                      QWidget *parent = 0);
     ~Comment();
 
+    void updateDataFromObject(ASObject *object);
+
     void fixLikeLabelText();
     void setLikesCount(QString count, QVariantList namesVariantList);
 
@@ -60,8 +62,15 @@ public:
     void syncAvatarFollowState();
 
     void setCommentContents();
+    void onResize();
     void getPendingImages();
 
+    QString getObjectId();
+
+    void setHint(QString color="");
+
+    void setCommentDeleted(QString deletedTime);
+
 
 signals:
     void commentQuoteRequested(QString content);
@@ -96,6 +105,8 @@ private:
     QLabel *contentLabel;
     HClabel *likesCountLabel;
 
+    QWidget *hintWidget;
+
     QLabel *likeLabel;
     QLabel *quoteLabel;
     QLabel *editLabel;
@@ -107,6 +118,7 @@ private:
 
     bool commentIsOwn;
     bool commentIsLiked;
+    bool commentIsDeleted;
     QString createdAt;
     QString updatedAt;
     QString commentOriginalText;
