@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,16 +22,24 @@
 
 CommenterBlock::CommenterBlock(PumpController *pumpController,
                                GlobalObject *globalObject,
+                               QString parentAuthorId,
+                               bool parentStandalone,
                                QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
     this->globalObj = globalObject;
+    this->parentPostAuthorId = parentAuthorId;
+    this->parentPostStandalone = parentStandalone;
+
     this->editingMode = false;
+    this->currentCommentCount = 0;
+    this->allCommentsShown = false;
 
     this->reloadCommentsString = tr("Reload comments");
     this->showAllCommentsLinkLabel = new QLabel("<a href=\"showall://\">"
                                                 + reloadCommentsString
-                                                + "</a>");
+                                                + "</a>",
+                                                this);
     showAllCommentsLinkLabel->setContextMenuPolicy(Qt::NoContextMenu);
     QFont showAllFont;
     showAllFont.setPointSize(showAllFont.pointSize() - 3);
@@ -42,23 +50,25 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     this->setContentsMargins(0, 0, 0, 0);
 
     commentsLayout = new QVBoxLayout();
-    commentsLayout->setAlignment(Qt::AlignTop);
     commentsLayout->setContentsMargins(0, 0, 0, 0);
+    commentsLayout->setSpacing(1);
 
-    commentsWidget = new QWidget();
+    commentsWidget = new QWidget(this);
+    commentsWidget->setContentsMargins(0, 0, 0, 0);
     QSizePolicy sizePolicy;
     sizePolicy.setHeightForWidth(false);
     sizePolicy.setWidthForHeight(false);
     sizePolicy.setHorizontalPolicy(QSizePolicy::Minimum);
-    sizePolicy.setVerticalPolicy(QSizePolicy::Minimum);
+    sizePolicy.setVerticalPolicy(QSizePolicy::Maximum);
     commentsWidget->setSizePolicy(sizePolicy);
     commentsWidget->setLayout(commentsLayout);
 
-    this->commentsScrollArea = new QScrollArea();
-    //commentsScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    this->commentsScrollArea = new QScrollArea(this);
     //commentsScrollArea->setFrameStyle(QFrame::NoFrame);
     commentsScrollArea->setContentsMargins(0, 0, 0, 0);
-    commentsScrollArea->setSizePolicy(sizePolicy);
+    //commentsScrollArea->setSizePolicy(sizePolicy);
+    commentsScrollArea->setSizePolicy(QSizePolicy::Minimum,
+                                      QSizePolicy::Preferred);
     commentsScrollArea->setWidget(commentsWidget);
     commentsScrollArea->setWidgetResizable(true);
 
@@ -78,11 +88,12 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
 
 
-    this->commentComposer = new Composer(false); // forPublisher = false
+    this->commentComposer = new Composer(this->globalObj,
+                                         false); // forPublisher = false
     this->commentComposer->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     this->commentComposer->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    this->commentComposer->setSizePolicy(QSizePolicy::Minimum,
-                                         QSizePolicy::Minimum);
+    this->commentComposer->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                         QSizePolicy::MinimumExpanding);
 
     connect(commentComposer, SIGNAL(editingFinished()),
             this, SLOT(sendComment()));
@@ -115,7 +126,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
 
     this->cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                           QIcon(":/images/button-cancel.png")),
-                                         tr("&Cancel"));
+                                         tr("Cancel"));
     cancelButton->setToolTip("<b></b>"
                              + tr("Press ESC to cancel the comment "
                                   "if there is no text"));
@@ -126,19 +137,18 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     bottomLayout = new QGridLayout();
     bottomLayout->setContentsMargins(0, 0, 0, 0);
     bottomLayout->setSpacing(1);
-    bottomLayout->addWidget(commentComposer,        0, 0, 4, 3);
+    bottomLayout->addWidget(commentComposer,        0, 0, 8, 3);
     bottomLayout->addWidget(toolsButton,            0, 3, 1, 1);
-    bottomLayout->addWidget(statusInfoLabel,        1, 3, 1, 1, Qt::AlignCenter);
-    bottomLayout->addWidget(commentButton,          2, 3, 1, 1);
-    bottomLayout->addWidget(cancelButton,           3, 3, 1, 1);
+    bottomLayout->addWidget(statusInfoLabel,        1, 3, 5, 1, Qt::AlignCenter);
+    bottomLayout->addWidget(commentButton,          6, 3, 1, 1);
+    bottomLayout->addWidget(cancelButton,           7, 3, 1, 1);
 
     mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(1);
     mainLayout->addWidget(showAllCommentsLinkLabel, 0, Qt::AlignRight | Qt::AlignTop);
-    mainLayout->addWidget(commentsScrollArea,       3);
+    mainLayout->addWidget(commentsScrollArea,       0);
     mainLayout->addLayout(bottomLayout,             0);
-
     this->setLayout(mainLayout);
 
     this->setMinimumMode();
@@ -162,53 +172,38 @@ void CommenterBlock::clearComments()
     }
 
     commentsInBlock.clear();
+    this->currentCommentCount = 0;
 }
 
 
 
 void CommenterBlock::setComments(QVariantList commentsList, int commentCount)
 {
-    this->clearComments();
-
     if (commentCount > 0)
     {
-        QString showAllString;
-        if (commentCount > commentsList.size())
+        // If some comments are actually included, clear first
+        if (commentsList.length() > 0)
         {
-            showAllString = tr("Show all %1 comments").arg(commentCount);
+            this->clearComments();
+        }
+
+        this->currentCommentCount = commentCount;
+        if (currentCommentCount > commentsList.size())
+        {
+            allCommentsShown = false;
         }
         else
         {
-            showAllString = this->reloadCommentsString;
+            allCommentsShown = true;
         }
+        this->updateShowAllLink();
 
-        // Small trick to avoid a bug where the link stops having appropriate mouse pointer
-        this->showAllCommentsLinkLabel->clear();
-        this->showAllCommentsLinkLabel->hide();
-
-        this->showAllCommentsLinkLabel->setText("<a href=\"showall://\">"
-                                                + showAllString
-                                                + "</a>");
-        this->showAllCommentsLinkLabel->show();
-
-        //this->adjustCommentsWidth();
 
         foreach (QVariant commentVariant, commentsList)
         {
             ASObject *commentObject = new ASObject(commentVariant.toMap(),
                                                    this);
-            Comment *comment = new Comment(this->pController,
-                                           this->globalObj,
-                                           commentObject,
-                                           this);
-            connect(comment, SIGNAL(commentQuoteRequested(QString)),
-                    this, SLOT(quoteComment(QString)));
-            connect(comment, SIGNAL(commentEditRequested(QString,QString)),
-                    this, SLOT(editComment(QString,QString)));
-
-            // Add the comment on top, since the list comes in reverse
-            this->commentsLayout->insertWidget(0, comment);
-            this->commentsInBlock.append(comment); // Keep track of it
+            this->appendComment(commentObject);
         }
 
         this->commentsScrollArea->show();
@@ -224,6 +219,116 @@ void CommenterBlock::setComments(QVariantList commentsList, int commentCount)
 }
 
 
+/*
+ * Add a single comment to the layout
+ *
+ */
+void CommenterBlock::appendComment(ASObject *object, bool justOne)
+{
+    foreach (Comment *previousComment, this->commentsInBlock)
+    {
+        if (previousComment->getObjectId() == object->getId())
+        {
+            return; // Comment is already present, so abort
+        }
+    }
+
+    Comment *comment = new Comment(this->pController,
+                                   this->globalObj,
+                                   object,
+                                   this);
+    connect(comment, SIGNAL(commentQuoteRequested(QString)),
+            this, SLOT(quoteComment(QString)));
+    connect(comment, SIGNAL(commentEditRequested(QString,QString)),
+            this, SLOT(editComment(QString,QString)));
+
+
+
+    // Highlight if the comment was made by the author of the parent post
+    if (this->globalObj->getPostHLAuthorComments()) // if configured to do so
+    {
+        if (object->author()->getId() == this->parentPostAuthorId)
+        {
+            comment->setHint(this->globalObj->getColor(4)); // HL filtering color
+        }
+    }
+
+    // Or highlight if this is our own comment, also optional
+    if (this->globalObj->getPostHLOwnComments())
+    {
+        if (object->author()->getId() == this->pController->currentUserId())
+        {
+            comment->setHint(this->globalObj->getColor(3)); // Your own posts color
+        }
+    }
+
+
+    // Add the comment at the end if it's just one (via MinorFeed), or at
+    // the top when it's part of a full list, since those lists come in reverse
+    this->commentsInBlock.append(comment); // First, keep track of it
+
+    if (justOne)
+    {
+        this->commentsLayout->addWidget(comment);
+        ++this->currentCommentCount;
+
+        // Check if we need to show "reload comments" or "show all X comments"
+        if (this->currentCommentCount == commentsInBlock.size())
+        {
+            this->allCommentsShown = true;
+        }
+        this->updateShowAllLink();
+
+        // Showing this is needed if there were 0 comments before
+        this->commentsScrollArea->show();
+
+        scrollToBottomTimer->start(500);
+    }
+    else  // called from setComments()
+    {
+        this->commentsLayout->insertWidget(0, comment);
+    }
+}
+
+
+void CommenterBlock::updateCommentFromObject(ASObject *object)
+{
+    foreach (Comment *comment, this->commentsInBlock)
+    {
+        if (comment->getObjectId() == object->getId())
+        {
+            comment->updateDataFromObject(object);
+        }
+    }
+
+    // FIXME: this needs some cheking...
+    commentsWidget->setMinimumHeight(10);
+    scrollToBottomTimer->start(500);
+
+    this->adjustCommentsHeight();
+    this->adjustCommentArea();
+}
+
+
+void CommenterBlock::setCommentDeletedFromObject(ASObject *object)
+{
+    foreach (Comment *comment, this->commentsInBlock)
+    {
+        if (comment->getObjectId() == object->getId())
+        {
+            comment->setCommentDeleted(object->getDeletedOnString());
+        }
+    }
+
+    // FIXME: this needs some cheking... and is copied from previous function
+    commentsWidget->setMinimumHeight(10);
+    scrollToBottomTimer->start(500);
+
+    this->adjustCommentsHeight();
+    this->adjustCommentArea();
+}
+
+
 void CommenterBlock::updateFuzzyTimestamps()
 {
     foreach (Comment *comment, this->commentsInBlock)
@@ -241,10 +346,70 @@ void CommenterBlock::updateAvatarFollowStates()
 }
 
 
+void CommenterBlock::updateShowAllLink()
+{
+    QString showAllString;
+    if (allCommentsShown)
+    {
+        showAllString = this->reloadCommentsString;
+    }
+    else
+    {
+        showAllString = tr("Show all %1 comments")
+                        .arg(this->currentCommentCount);
+    }
+
+    // Small trick to avoid a bug where the link stops having appropriate mouse pointer
+    this->showAllCommentsLinkLabel->clear();
+    this->showAllCommentsLinkLabel->hide();
+
+    this->showAllCommentsLinkLabel->setText("<a href=\"showall://\">"
+                                            + showAllString
+                                            + "</a>");
+    this->showAllCommentsLinkLabel->show();
+}
+
+
 
 void CommenterBlock::adjustCommentsWidth()
 {
-    commentsWidget->setMaximumWidth(commentsScrollArea->viewport()->width() - 2);
+    //commentsWidget->setMaximumWidth(commentsScrollArea->viewport()->width() - 2);
+}
+
+void CommenterBlock::adjustCommentsHeight()
+{
+    if (this->commentsScrollArea->isVisible())
+    {
+        this->commentsScrollArea->hide();
+        this->commentsScrollArea->show();
+    }
+}
+
+
+void CommenterBlock::adjustCommentArea()
+{
+    this->commentsWidget->ensurePolished(); // So .height() is valid
+    int commentsWidgetHeight = qMax(this->commentsWidget->height(),
+                                    32); // 32 px min! (size of avatar)
+    int goodScrollAreaHeight = qMin(commentsWidgetHeight,
+                                    globalObj->getTimelineHeight()); // Not bigger than the window
+    goodScrollAreaHeight += commentsScrollArea->frameWidth() * 2; // Account for the frame
+
+    if (!parentPostStandalone)
+    {
+        // Minimum is set only when the post is not open as standalone
+        this->commentsScrollArea->setMinimumHeight(goodScrollAreaHeight);
+    }
+    this->commentsScrollArea->setMaximumHeight(goodScrollAreaHeight);
+}
+
+
+void CommenterBlock::redrawComments()
+{
+    foreach (Comment *comment, this->commentsInBlock)
+    {
+        comment->setCommentContents();
+    }
 }
 
 
@@ -254,6 +419,12 @@ bool CommenterBlock::isFullMode()
 }
 
 
+int CommenterBlock::getCommentCount()
+{
+    return this->currentCommentCount;
+}
+
+
 Composer *CommenterBlock::getComposer()
 {
     return this->commentComposer;
@@ -261,9 +432,9 @@ Composer *CommenterBlock::getComposer()
 
 
 
-/*******************************************************************/
-/****************************** SLOTS ******************************/
-/*******************************************************************/
+/*****************************************************************************/
+/*********************************** SLOTS ***********************************/
+/*****************************************************************************/
 
 
 
@@ -289,9 +460,6 @@ void CommenterBlock::setMinimumMode()
                                         "Infinitive verb")); // With exact same comment, so it's 1 entry
     }
 
-    // Unblock updates to timeline, since we're done commenting
-    this->pController->setUpdatesToTimelineBlocked(false);
-
     this->fullMode = false;
 }
 
@@ -307,13 +475,6 @@ void CommenterBlock::setFullMode(QString initialText)
 
     this->commentComposer->setFocus();
     this->commentComposer->append(initialText);
-
-    // Block updates to timeline while we're commenting...
-    this->pController->setUpdatesToTimelineBlocked(true);
-
-    // FIXME: this fails if user clicks "comment" in 2 posts, and then
-    // cancels or sends one of them
-
     this->fullMode = true;
 }
 
@@ -321,8 +482,7 @@ void CommenterBlock::setFullMode(QString initialText)
 
 void CommenterBlock::quoteComment(QString content)
 {
-    this->setFullMode();
-    this->commentComposer->append(content); // FIXME 1.3: redundant? could call setFullMode(content)
+    this->setFullMode(content); // FIXME: connect to setFullMode(QString) directly?
 }
 
 
@@ -387,7 +547,7 @@ void CommenterBlock::onPostingCommentOk()
                this, SLOT(onPostingCommentFailed()));
 
 
-    this->getAllCommentsTimer->start(2000); // Request comments after a delay
+    this->getAllCommentsTimer->start(3000); // Request comments after a delay
 }
 
 
@@ -456,33 +616,32 @@ void CommenterBlock::sendComment()
 void CommenterBlock::scrollCommentsToBottom()
 {
     this->adjustCommentsWidth();
+    this->adjustCommentArea();
 
     commentsScrollArea->verticalScrollBar()->triggerAction(QScrollBar::SliderToMaximum);
 }
 
 
 
-
-/*******************************************************************/
-/**************************** PROTECTED ****************************/
-/*******************************************************************/
+/*****************************************************************************/
+/********************************* PROTECTED *********************************/
+/*****************************************************************************/
 
 
 
 void CommenterBlock::resizeEvent(QResizeEvent *event)
 {
-    qDebug() << "CommenterBlock::resizeEvent()"
-             << event->oldSize() << ">" << event->size();
+    //qDebug() << "CommenterBlock::resizeEvent()"
+    //         << event->oldSize() << ">" << event->size();
 
     this->adjustCommentsWidth();
 
-    foreach (Comment *comment, this->commentsInBlock)
-    {
-        comment->setCommentContents();
-    }
+    this->redrawComments();
+
 
     //this->commentsWidget->adjustSize();
     //this->commentsScrollArea->adjustSize();
+    this->adjustCommentArea();
 
     event->accept();
 }
