@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -44,18 +44,30 @@ class CommenterBlock : public QWidget
 public:
     explicit CommenterBlock(PumpController *pumpController,
                             GlobalObject *globalObject,
+                            QString parentAuthorId,
+                            bool parentStandalone,
                             QWidget *parent = 0);
     ~CommenterBlock();
 
     void clearComments();
     void setComments(QVariantList commentsList, int commentCount);
+    void appendComment(ASObject *object, bool justOne=false);
+    void updateCommentFromObject(ASObject *object);
+    void setCommentDeletedFromObject(ASObject *object);
+
     void updateFuzzyTimestamps();
     void updateAvatarFollowStates();
+    void updateShowAllLink();
 
     void adjustCommentsWidth();
+    void adjustCommentsHeight();
+    void adjustCommentArea();
+    void redrawComments();
 
     bool isFullMode();
 
+    int getCommentCount();
+
     Composer *getComposer();
 
 
@@ -111,6 +123,11 @@ private:
     bool fullMode;
 
     QList<Comment *> commentsInBlock;
+    int currentCommentCount;
+    bool allCommentsShown;
+
+    QString parentPostAuthorId;
+    bool parentPostStandalone;
 
     PumpController *pController;
     GlobalObject *globalObj;
