@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,8 +21,9 @@
 #include "composer.h"
 
 
-Composer::Composer(bool forPublisher)
+Composer::Composer(GlobalObject *globalObject, bool forPublisher)
 {
+    this->globalObj = globalObject;
     this->forPublisher = forPublisher;
 
     this->setAcceptRichText(true);
@@ -148,8 +149,18 @@ Composer::Composer(bool forPublisher)
 
     // Add action to this object, in order for the shortcut to work
     // Otherwise, the action isn't available until the context menu is present
-    this->addAction(pastePlaintextAction); // FIXME QAction::eventFilter:
-                                           // Ambiguous shortcut overload: Ctrl+Shift+V
+    this->addAction(pastePlaintextAction);
+
+
+    // Nick completion stuff
+    nickCompleter = new QCompleter(globalObj->getNickCompletionModel(),
+                                   this);
+    nickCompleter->setWidget(this);
+    nickCompleter->setMaxVisibleItems(10);
+    nickCompleter->setCaseSensitivity(Qt::CaseInsensitive);
+    nickCompleter->setModelSorting(QCompleter::CaseSensitivelySortedModel); // TMP; FIXME
+    connect(nickCompleter, SIGNAL(activated(QModelIndex)),
+            this, SLOT(insertCompletedNick(QModelIndex)));
 
     mainLayout = new QHBoxLayout();
 
@@ -209,9 +220,21 @@ void Composer::insertLink(QString url, QString title)
     if (this->textCursor().atEnd() || !prettyLink)
     {
         this->insertHtml("&nbsp;");
+        // Could use this->makeNormal(), but has some drawbacks
     }
 }
 
+
+void Composer::requestCompletion(QString partialNick)
+{
+    nickCompleter->setCompletionPrefix(partialNick);
+
+    nickCompleter->complete(QRect(this->cursorRect().x(),
+                                  this->cursorRect().y(),
+                                  256, 1));
+}
+
+
 int Composer::getMessageLabelHeight()
 {
     // kinda TMP / FIXME
@@ -229,6 +252,31 @@ void Composer::hideInfoMessage()
 }
 
 
+QPushButton *Composer::getToolsButton()
+{
+    return this->toolsButton;
+}
+
+
+/*
+ * Enable or disable the Ctrl+Shift+V action to paste without format
+ *
+ * Needed to avoid this conflict between Publisher and Commenters:
+ *
+ *   QAction::eventFilter: Ambiguous shortcut overload: Ctrl+Shift+V
+ *
+ */
+void Composer::setPlainPasteEnabled(bool state)
+{
+    this->pastePlaintextAction->setEnabled(state);
+}
+
+
+/*****************************************************************************/
+/****************************** PROTECTED ************************************/
+/*****************************************************************************/
+
+
 /*
  * Send a signal when getting focus
  *
@@ -247,6 +295,18 @@ void Composer::keyPressEvent(QKeyEvent *event)
 {
     //qDebug() << "Composer::keyPressEvent()";
 
+    // Allow canceling/accepting the autocompletion popup
+    if (this->nickCompleter->popup()->isVisible())
+    {
+        if (event->key() == Qt::Key_Enter
+         || event->key() == Qt::Key_Return
+         || event->key() == Qt::Key_Escape)
+        {
+            event->ignore();
+            return;
+        }
+    }
+
 
     // Control+Enter = Send message (post)
     if ((event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return)
@@ -272,6 +332,22 @@ void Composer::keyPressEvent(QKeyEvent *event)
     else
     {
         QTextEdit::keyPressEvent(event);
+
+        QTextCursor textCursor = this->textCursor();
+        textCursor.select(QTextCursor::WordUnderCursor);
+
+        //if (event->key() == Qt::Key_At)
+        if (textCursor.document()->characterAt(textCursor.selectionStart() - 1)
+            == QChar('@'))
+        {
+            // Show completer
+            this->requestCompletion(textCursor.selectedText());
+        }
+        else
+        {
+            // Hide it, if it was visible
+            this->nickCompleter->popup()->hide();
+        }
     }
 
     event->accept();
@@ -327,6 +403,7 @@ void Composer::insertFromMimeData(const QMimeData *source)
     {
         int insertionType = 1;
 
+        // If link looks like an image, ask the user how to insert it
         if (pastedText.endsWith(".png", Qt::CaseInsensitive)
          || pastedText.endsWith(".jpg", Qt::CaseInsensitive)
          || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
@@ -358,9 +435,9 @@ void Composer::insertFromMimeData(const QMimeData *source)
 
 
 
-/*************************************************************************/
-/****************************** SLOTS ************************************/
-/*************************************************************************/
+/*****************************************************************************/
+/******************************** SLOTS **************************************/
+/*****************************************************************************/
 
 
 
@@ -683,6 +760,32 @@ void Composer::pasteAsPlaintext()
 
 
 
+/*
+ * Insert the selected nick chosen from the autocomplete list.
+ * Notify the parent object about it so the user can be added
+ * to To/Cc.
+ *
+ */
+void Composer::insertCompletedNick(QModelIndex nickData)
+{
+    QTextCursor textCursor = this->textCursor();
+    textCursor.select(QTextCursor::WordUnderCursor);
+    textCursor.removeSelectedText();
+
+    QString nickId = nickData.data(Qt::UserRole + 1).toString();
+    QString nickName = nickData.data().toString();
+    QString nickUrl = nickData.data(Qt::UserRole + 2).toString();
+
+    this->insertHtml("<a href=\"" + nickUrl + "\">"
+                     + nickName + "</a>");
+    this->makeNormal();
+
+    // Send signal for Publisher(), to add to the "To" field
+    emit nickInserted(nickId, nickName, nickUrl);
+}
+
+
+
 
 /*
  * Cancel editing of the post, clear it, return to minimum mode
@@ -719,8 +822,3 @@ void Composer::cancelPost()
 
 
 }
-
-QPushButton *Composer::getToolsButton()
-{
-    return this->toolsButton;
-}
