@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,9 +22,8 @@
 
 ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                            QString dataDirectory, int updateInterval,
-                           int postsPerPageMain, int postsPerPageOther,
                            int tabsPosition, bool tabsMovable,
-                           bool publicPosts, FDNotifications *notifier,
+                           FDNotifications *notifier,
                            QWidget *parent) : QWidget(parent)
 {
     this->globalObj = globalObject;
@@ -48,7 +47,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     settings.beginGroup("Configuration");
 
     // Standalone Proxy config window
-    QByteArray proxyPasswd = QByteArray::fromBase64(settings.value("proxyPassword").toByteArray());
+    QByteArray proxyPasswd = QByteArray::fromBase64(settings.value("proxyPassword")
+                                                            .toByteArray());
     proxyDialog = new ProxyDialog(settings.value("proxyType", 0).toInt(),
                                   settings.value("proxyHostname").toString(),
                                   settings.value("proxyPort").toString(),
@@ -71,11 +71,6 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                  updateIntervalSpinbox);
 
 
-    publicPostsCheckbox = new QCheckBox();
-    publicPostsCheckbox->setChecked(publicPosts);
-    generalOptionsLayout->addRow(tr("Public posts as &default"),
-                                 publicPostsCheckbox);
-
     // ------------------------------------------------
     QFrame *lineFrame1 = new QFrame();
     lineFrame1->setFrameStyle(QFrame::HLine);
@@ -138,7 +133,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                  globalObj->getPostContentsFont());
     fontPicker3 = new FontPicker(tr("Comments"),
                                  globalObj->getCommentsFont());
-    fontPicker4 = new FontPicker(tr("Minor Feed"),
+    fontPicker4 = new FontPicker(tr("Minor Feeds"),
                                  globalObj->getMinorFeedFont());
     // FIXME: more for "Timestamps" or something else?
     // FIXME: add a "base font size" option
@@ -164,18 +159,21 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                    + "\n"
                                    + tr("Used also when highlighting posts "
                                         "addressed to you in the timelines."),
-                                   colorList.at(0));
+                                   colorList.at(0),
+                                   this);
     colorOptionsLayout->addWidget(colorPicker1);
 
     colorPicker2 = new ColorPicker(tr("The activity is in reply to something "
                                       "done by you, such as a comment posted "
                                       "in reply to one of your notes."),
-                                   colorList.at(1));
+                                   colorList.at(1),
+                                   this);
     colorOptionsLayout->addWidget(colorPicker2);
 
     colorPicker3 = new ColorPicker(tr("You are the object of the activity, "
                                       "such as someone adding you to a list."),
-                                   colorList.at(2));
+                                   colorList.at(2),
+                                   this);
     colorOptionsLayout->addWidget(colorPicker3);
 
     colorPicker4 = new ColorPicker(tr("The activity is related to one of "
@@ -184,19 +182,22 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                    + "\n"
                                    + tr("Used also when highlighting your "
                                         "own posts in the timelines."),
-                                   colorList.at(3));
+                                   colorList.at(3),
+                                   this);
     colorOptionsLayout->addWidget(colorPicker4);
 
     colorPicker5 = new ColorPicker(tr("Item highlighted due to filtering rules."),
-                                   colorList.at(4));
+                                   colorList.at(4),
+                                   this);
     colorOptionsLayout->addWidget(colorPicker5);
 
     colorPicker6 = new ColorPicker(tr("Item is new."),
-                                   colorList.at(5));
+                                   colorList.at(5),
+                                   this);
     colorOptionsLayout->addWidget(colorPicker6);
 
 
-    colorOptionsWidget = new QWidget();
+    colorOptionsWidget = new QWidget(this);
     colorOptionsWidget->setLayout(colorOptionsLayout);
 
 
@@ -204,34 +205,34 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Page 4, timelines options
     timelinesOptionsLayout = new QFormLayout();
 
-    postsPerPageMainSpinbox = new QSpinBox();
+    postsPerPageMainSpinbox = new QSpinBox(this);
     postsPerPageMainSpinbox->setRange(5, 50); // 5-50 ppp
     postsPerPageMainSpinbox->setSuffix(" "+ tr("posts",
                                                "Goes after a number, as: "
                                                "25 posts"));
-    postsPerPageMainSpinbox->setValue(postsPerPageMain);
+    postsPerPageMainSpinbox->setValue(globalObj->getPostsPerPageMain());
     timelinesOptionsLayout->addRow(tr("&Posts per page, main timeline"),
                                    postsPerPageMainSpinbox);
 
-    postsPerPageOtherSpinbox = new QSpinBox();
+    postsPerPageOtherSpinbox = new QSpinBox(this);
     postsPerPageOtherSpinbox->setRange(1, 30); // 1-30 ppp
     postsPerPageOtherSpinbox->setSuffix(" "+ tr("posts",
                                                 "This goes after a number, "
                                                 "like: 10 posts"));
-    postsPerPageOtherSpinbox->setValue(postsPerPageOther);
+    postsPerPageOtherSpinbox->setValue(globalObj->getPostsPerPageOther());
     timelinesOptionsLayout->addRow(tr("Posts per page, &other timelines"),
                                    postsPerPageOtherSpinbox);
 
-    minorFeedSnippetsCombobox = new QComboBox();
+    minorFeedSnippetsCombobox = new QComboBox(this);
     minorFeedSnippetsCombobox->addItem(tr("Highlighted activities, except mine"));
     minorFeedSnippetsCombobox->addItem(tr("Any highlighted activity"));
     minorFeedSnippetsCombobox->addItem(tr("Always"));
     minorFeedSnippetsCombobox->addItem(tr("Never"));
     minorFeedSnippetsCombobox->setCurrentIndex(globalObj->getMinorFeedSnippetsType());
-    timelinesOptionsLayout->addRow(tr("Show snippets in minor feed"),
+    timelinesOptionsLayout->addRow(tr("Show snippets in minor feeds"),
                                    minorFeedSnippetsCombobox);
 
-    snippetLimitSpinbox = new QSpinBox();
+    snippetLimitSpinbox = new QSpinBox(this);
     snippetLimitSpinbox->setRange(10, 10000);
     snippetLimitSpinbox->setSuffix(" " + tr("characters",
                                             "This is a suffix, after a number"));
@@ -239,87 +240,175 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     timelinesOptionsLayout->addRow(tr("Snippet limit"),
                                    snippetLimitSpinbox);
 
-    timelinesOptionsWidget = new QWidget();
+    showDeletedCheckbox = new QCheckBox(this);
+    showDeletedCheckbox->setChecked(globalObj->getShowDeleted());
+    //timelinesOptionsLayout->addRow("Show frame of deleted posts", // Not translatable for now
+    //                               showDeletedCheckbox);
+    showDeletedCheckbox->hide(); // Hidden option for now (FIXME v1.3.1)
+
+    hideDuplicatesCheckbox = new QCheckBox(this);
+    hideDuplicatesCheckbox->setChecked(globalObj->getHideDuplicates());
+    timelinesOptionsLayout->addRow(tr("Hide duplicated posts"),
+                                   hideDuplicatesCheckbox);
+
+
+    timelinesOptionsWidget = new QWidget(this);
     timelinesOptionsWidget->setLayout(timelinesOptionsLayout);
 
 
 
     // Page 5, posts options
-    showExtraInfoCheckbox = new QCheckBox();
+    postAvatarSizeCombobox = new QComboBox(this);
+    postAvatarSizeCombobox->addItem("32x32");
+    postAvatarSizeCombobox->addItem("48x48");
+    postAvatarSizeCombobox->addItem("64x64");
+    postAvatarSizeCombobox->addItem("96x96");
+    postAvatarSizeCombobox->addItem("128x128");
+    postAvatarSizeCombobox->addItem("256x256");
+    postAvatarSizeCombobox->setCurrentIndex(globalObj->getPostAvatarSizeIndex());
+
+    showExtendedSharesCheckbox = new QCheckBox(this);
+    showExtendedSharesCheckbox->setChecked(globalObj->getPostExtendedShares());
+
+    showExtraInfoCheckbox = new QCheckBox(this);
     showExtraInfoCheckbox->setChecked(globalObj->getPostShowExtraInfo());
 
+    postHLAuthorCommentsCheckbox = new QCheckBox(this);
+    postHLAuthorCommentsCheckbox->setChecked(globalObj->getPostHLAuthorComments());
+
+    postHLOwnCommentsCheckbox = new QCheckBox(this);
+    postHLOwnCommentsCheckbox->setChecked(globalObj->getPostHLOwnComments());
+
+    postIgnoreSslInImages = new QCheckBox(tr("Only for images inserted from "
+                                             "web sites.")
+                                          + "\n"
+                                          + tr("Use with care."),
+                                          this);
+    postIgnoreSslInImages->setChecked(globalObj->getPostIgnoreSslInImages());
+
     postsOptionsLayout = new QFormLayout();
+    postsOptionsLayout->addRow(tr("Avatar size"),
+                               postAvatarSizeCombobox);
+    postsOptionsLayout->addRow(tr("Show extended share information"),
+                               showExtendedSharesCheckbox);
     postsOptionsLayout->addRow(tr("Show extra information"),
                                showExtraInfoCheckbox);
+    postsOptionsLayout->addRow(tr("Highlight post author's comments"),
+                               postHLAuthorCommentsCheckbox);
+    postsOptionsLayout->addRow(tr("Highlight your own comments"),
+                               postHLOwnCommentsCheckbox);
+    postsOptionsLayout->addRow(tr("Ignore SSL errors in images"),
+                               postIgnoreSslInImages);
 
-    postsOptionsWidget = new QWidget();
+    postsOptionsWidget = new QWidget(this);
     postsOptionsWidget->setLayout(postsOptionsLayout);
 
 
 
-    // Page 6, notifications options
+    // Page 6, composer options
+    publicPostsCheckbox = new QCheckBox(this);
+    publicPostsCheckbox->setChecked(globalObj->getPublicPostsByDefault());
+
+    useFilenameAsTitleCheckbox = new QCheckBox(this);
+    useFilenameAsTitleCheckbox->setChecked(globalObj->getUseFilenameAsTitle());
+
+    showCharacterCounterCheckbox = new QCheckBox(this);
+    showCharacterCounterCheckbox->setChecked(globalObj->getShowCharacterCounter());
+
+    composerOptionsLayout = new QFormLayout();
+    composerOptionsLayout->addRow(tr("Public posts as &default"),
+                                  publicPostsCheckbox);
+    composerOptionsLayout->addRow(tr("Use attachment filename as initial post title"),
+                                  useFilenameAsTitleCheckbox);
+    composerOptionsLayout->addRow(tr("Show character counter"),
+                                  showCharacterCounterCheckbox);
+
+    composerOptionsWidget = new QWidget(this);
+    composerOptionsWidget->setLayout(composerOptionsLayout);
+
+
+
+    // Page 7, notifications options
     notificationOptionsLayout = new QFormLayout();
 
-    notificationStyleCombobox = new QComboBox();
+    notificationStyleCombobox = new QComboBox(this);
     notificationStyleCombobox->addItem(QIcon::fromTheme("preferences-desktop-notification"),
                                        tr("As system notifications"));
     notificationStyleCombobox->addItem(QIcon::fromTheme("view-conversation-balloon"),
                                        tr("Using own notifications"));
     notificationStyleCombobox->addItem(QIcon::fromTheme("user-busy"), // dialog-cancel
                                        tr("Don't show notifications"));
-    notificationStyleCombobox->setCurrentIndex(settings.value("showNotifications", 0).toInt());
+    notificationStyleCombobox->setCurrentIndex(settings.value("showNotifications",
+                                                              0).toInt());
     notificationOptionsLayout->addRow(tr("Notification Style"),
                                       notificationStyleCombobox);
 
+    notificationsStatusLabel = new QLabel(this);
+    notificationOptionsLayout->addRow("", // Empty label on left to align with right column
+                                      notificationsStatusLabel);
 
-    notificationOptionsLayout->addRow(new QLabel("\n" + tr("Notify when receiving:")));
 
-    notifyNewTLCheckbox = new QCheckBox();
+    notificationOptionsLayout->addRow(new QLabel("\n"
+                                                 + tr("Notify when receiving:"),
+                                                 this));
+
+    notifyNewTLCheckbox = new QCheckBox(this);
     notifyNewTLCheckbox->setChecked(settings.value("notifyNewTL", false).toBool());
     notificationOptionsLayout->addRow(tr("New posts"),
                                       notifyNewTLCheckbox);
 
-    notifyHLTLCheckbox = new QCheckBox();
+    notifyHLTLCheckbox = new QCheckBox(this);
     notifyHLTLCheckbox->setChecked(settings.value("notifyHLTL", true).toBool());
     notificationOptionsLayout->addRow(tr("Highlighted posts"),
                                       notifyHLTLCheckbox);
 
-    notifyNewMWCheckbox = new QCheckBox();
+    notifyNewMWCheckbox = new QCheckBox(this);
     notifyNewMWCheckbox->setChecked(settings.value("notifyNewMW", false).toBool());
     notificationOptionsLayout->addRow(tr("New activities in minor feed"),
                                       notifyNewMWCheckbox);
 
-    notifyHLMWCheckbox = new QCheckBox();
+    notifyHLMWCheckbox = new QCheckBox(this);
     notifyHLMWCheckbox->setChecked(settings.value("notifyHLMW", true).toBool());
     notificationOptionsLayout->addRow(tr("Highlighted activities in minor feed"),
                                       notifyHLMWCheckbox);
 
     this->syncNotifierOptions();
 
-    notificationOptionsWidget = new QWidget();
+    // Initial check to see if currently selected style is available
+    this->checkNotifications(notificationStyleCombobox->currentIndex());
+
+    notificationOptionsWidget = new QWidget(this);
     notificationOptionsWidget->setLayout(notificationOptionsLayout);
 
+    // Check FD.org notifications availability when selecting an option
+    connect(notificationStyleCombobox, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(showDemoNotification(int)));
 
 
-    // Page 7, systray options
+
+    // Page 8, systray options
     systrayOptionsLayout = new QFormLayout();
 
-    systrayIconTypeCombobox = new QComboBox();
+    systrayIconTypeCombobox = new QComboBox(this);
     systrayIconTypeCombobox->addItem(tr("Default"));
     systrayIconTypeCombobox->addItem(tr("System iconset, if available"));
     systrayIconTypeCombobox->addItem(tr("Show your current avatar"));
     systrayIconTypeCombobox->addItem(tr("Custom icon"));
-    systrayIconTypeCombobox->setCurrentIndex(settings.value("systrayIconType", 0).toInt());
+    systrayIconTypeCombobox->setCurrentIndex(settings.value("systrayIconType",
+                                                            0).toInt());
     systrayOptionsLayout->addRow(tr("System Tray Icon &Type"),
                                  systrayIconTypeCombobox);
 
-    systrayCustomIconButton = new QPushButton(tr("S&elect..."));
+    systrayCustomIconButton = new QPushButton(tr("S&elect..."), this);
+    systrayIconLastUsedDir = QDir::homePath();
     systrayCustomIconFN = settings.value("systrayCustomIconFN").toString();
     // FIXME: merge this with code used in pickCustomIconFile()
     // and turn the warning messageBox into a label
     if (!QPixmap(systrayCustomIconFN).isNull())
     {
         systrayCustomIconButton->setIcon(QIcon(systrayCustomIconFN));
+        systrayCustomIconButton->setToolTip("<b></b>"
+                                            + systrayCustomIconFN);
     }
     else
     {
@@ -330,7 +419,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     systrayOptionsLayout->addRow(tr("Custom &Icon"),
                                  systrayCustomIconButton);
 
-    systrayOptionsWidget = new QWidget();
+    systrayOptionsWidget = new QWidget(this);
     systrayOptionsWidget->setLayout(systrayOptionsLayout);
 
     settings.endGroup();
@@ -369,11 +458,14 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesListWidget->addItem(tr("Posts"));
     categoriesListWidget->item(4)->setIcon(QIcon::fromTheme("mail-message",
                                                             QIcon(":/images/button-post.png")));
+    categoriesListWidget->addItem(tr("Composer"));
+    categoriesListWidget->item(5)->setIcon(QIcon::fromTheme("document-edit",
+                                                            QIcon(":/images/button-edit.png")));
     categoriesListWidget->addItem(tr("Notifications"));
-    categoriesListWidget->item(5)->setIcon(QIcon::fromTheme("preferences-desktop-notification",
+    categoriesListWidget->item(6)->setIcon(QIcon::fromTheme("preferences-desktop-notification",
                                                             QIcon(":/images/button-online.png")));
     categoriesListWidget->addItem(tr("System Tray"));     // dashboard-show ?
-    categoriesListWidget->item(6)->setIcon(QIcon::fromTheme("configure-toolbars",
+    categoriesListWidget->item(7)->setIcon(QIcon::fromTheme("configure-toolbars",
                                                             QIcon(":/images/button-configure.png")));
 
     categoriesStackedWidget = new QStackedWidget();
@@ -384,6 +476,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesStackedWidget->addWidget(colorOptionsWidget);
     categoriesStackedWidget->addWidget(timelinesOptionsWidget);
     categoriesStackedWidget->addWidget(postsOptionsWidget);
+    categoriesStackedWidget->addWidget(composerOptionsWidget);
     categoriesStackedWidget->addWidget(notificationOptionsWidget);
     categoriesStackedWidget->addWidget(systrayOptionsWidget);
 
@@ -467,6 +560,43 @@ void ConfigDialog::syncNotifierOptions()
 }
 
 
+/*
+ * Get a demo message for the current notification style
+ *
+ * Show also a warning is system notifications are not available
+ *
+ */
+QString ConfigDialog::checkNotifications(int notificationStyle)
+{
+    QString demoText;
+    if (notificationStyle == FDNotifications::SystemNotifications)
+    {
+        if (fdNotifier->areNotificationsAvailable())
+        {
+            demoText = tr("This is a system notification");
+        }
+        else
+        {
+            demoText = tr("System notifications are not available!")
+                       + "<br>"
+                       + tr("Own notifications will be used.");
+            notificationsStatusLabel->setText("<i>"
+                                              + demoText
+                                              + "</i>");
+            /* FIXME: Should also check availability of system tray icon,
+             *        needed to show Qt's balloon notifications
+             */
+        }
+    }
+    else
+    {
+        demoText = tr("This is a basic notification");
+    }
+
+    return demoText;
+}
+
+
 
 //////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////// SLOTS //////////////////////////////////////
@@ -477,11 +607,18 @@ void ConfigDialog::syncNotifierOptions()
 void ConfigDialog::saveConfiguration()
 {
     QSettings settings;
+    if (!settings.isWritable())
+    {
+        // TMP FIXME: notify user properly
+
+        qDebug() << "ERROR SAVING CONFIGURATION (maybe disk full?)";
+        return;
+    }
+
     settings.beginGroup("Configuration");
 
     // General
     settings.setValue("updateInterval", this->updateIntervalSpinbox->value());
-    settings.setValue("publicPosts", this->publicPostsCheckbox->isChecked());
 
     settings.setValue("tabsPosition", this->tabsPositionCombobox->currentIndex());
     settings.setValue("tabsMovable",  this->tabsMovableCheckbox->isChecked());
@@ -516,20 +653,57 @@ void ConfigDialog::saveConfiguration()
 
 
     // Timelines
-    settings.setValue("postsPerPageMain",  this->postsPerPageMainSpinbox->value());
-    settings.setValue("postsPerPageOther", this->postsPerPageOtherSpinbox->value());
+    settings.setValue("postsPerPageMain",
+                      this->postsPerPageMainSpinbox->value());
+    settings.setValue("postsPerPageOther",
+                      this->postsPerPageOtherSpinbox->value());
     settings.setValue("minorFeedSnippets",
                       this->minorFeedSnippetsCombobox->currentIndex());
     settings.setValue("snippetsCharLimit",
                       this->snippetLimitSpinbox->value());
+    settings.setValue("showDeletedPosts",
+                      this->showDeletedCheckbox->isChecked());
+    settings.setValue("hideDuplicatedPosts",
+                      this->hideDuplicatesCheckbox->isChecked());
 
-    this->globalObj->syncTimelinesSettings(this->minorFeedSnippetsCombobox->currentIndex(),
-                                           this->snippetLimitSpinbox->value());
+    this->globalObj->syncTimelinesSettings(this->postsPerPageMainSpinbox->value(),
+                                           this->postsPerPageOtherSpinbox->value(),
+                                           this->minorFeedSnippetsCombobox->currentIndex(),
+                                           this->snippetLimitSpinbox->value(),
+                                           this->showDeletedCheckbox->isChecked(),
+                                           this->hideDuplicatesCheckbox->isChecked());
 
     // Posts
+    settings.setValue("postAvatarSizeIndex",
+                      this->postAvatarSizeCombobox->currentIndex());
+    settings.setValue("postExtendedShares",
+                      this->showExtendedSharesCheckbox->isChecked());
     settings.setValue("postShowExtraInfo",
                       this->showExtraInfoCheckbox->isChecked());
-    this->globalObj->syncPostSettings(this->showExtraInfoCheckbox->isChecked());
+    settings.setValue("postHLAuthorComments",
+                      this->postHLAuthorCommentsCheckbox->isChecked());
+    settings.setValue("postHLOwnComments",
+                      this->postHLOwnCommentsCheckbox->isChecked());
+    settings.setValue("postIgnoreSslInImages",
+                      this->postIgnoreSslInImages->isChecked());
+    this->globalObj->syncPostSettings(this->postAvatarSizeCombobox->currentIndex(),
+                                      this->showExtendedSharesCheckbox->isChecked(),
+                                      this->showExtraInfoCheckbox->isChecked(),
+                                      this->postHLAuthorCommentsCheckbox->isChecked(),
+                                      this->postHLOwnCommentsCheckbox->isChecked(),
+                                      this->postIgnoreSslInImages->isChecked());
+
+
+    // Composer
+    settings.setValue("publicPosts",
+                      this->publicPostsCheckbox->isChecked());
+    settings.setValue("useFilenameAsTitle",
+                      this->useFilenameAsTitleCheckbox->isChecked());
+    settings.setValue("showCharacterCounter",
+                      this->showCharacterCounterCheckbox->isChecked());
+    this->globalObj->syncComposerSettings(this->publicPostsCheckbox->isChecked(),
+                                          this->useFilenameAsTitleCheckbox->isChecked(),
+                                          this->showCharacterCounterCheckbox->isChecked());
 
 
     // Notifications
@@ -540,10 +714,14 @@ void ConfigDialog::saveConfiguration()
     settings.setValue("notifyNewMW", this->notifyNewMWCheckbox->isChecked());
     settings.setValue("notifyHLMW",  this->notifyHLMWCheckbox->isChecked());
     this->syncNotifierOptions();
+    this->globalObj->syncNotificationSettings(); // FIXME, still empty
+
 
     // Tray
     settings.setValue("systrayIconType", this->systrayIconTypeCombobox->currentIndex());
     settings.setValue("systrayCustomIconFN", this->systrayCustomIconFN);
+    this->globalObj->syncTrayOptions(); // FIXME, still empty
+
 
     settings.endGroup();
 
@@ -562,7 +740,7 @@ void ConfigDialog::pickCustomIconFile()
 {
     systrayCustomIconFN = QFileDialog::getOpenFileName(this,
                                                        tr("Select custom icon"),
-                                                       QDir::homePath(),
+                                                       systrayIconLastUsedDir,
                                                        tr("Image files")
                                                        + " (*.png *.jpg *.jpeg *.gif);;"
                                                        + tr("All files") + " (*)");
@@ -570,11 +748,15 @@ void ConfigDialog::pickCustomIconFile()
     if (!systrayCustomIconFN.isEmpty())
     {
         qDebug() << "Selected" << systrayCustomIconFN << "as new custom tray icon";
+        QFileInfo fileInfo(systrayCustomIconFN);
+        this->systrayIconLastUsedDir = fileInfo.path();
 
         QPixmap iconPixmap = QPixmap(systrayCustomIconFN);
         if (!iconPixmap.isNull())
         {
             this->systrayCustomIconButton->setIcon(QIcon(systrayCustomIconFN));
+            this->systrayCustomIconButton->setToolTip("<b></b>"
+                                                      + systrayCustomIconFN);
         }
         else
         {
@@ -587,6 +769,23 @@ void ConfigDialog::pickCustomIconFile()
 }
 
 
+void ConfigDialog::showDemoNotification(int notificationStyle)
+{
+    notificationsStatusLabel->clear();
+
+    if (notificationStyle == FDNotifications::NoNotifications)
+    {
+        return;
+    }
+
+
+    this->syncNotifierOptions();
+
+    QString demoNotificationText = this->checkNotifications(notificationStyle);
+    this->fdNotifier->showMessage(demoNotificationText);
+}
+
+
 //////////////////////////////////////////////////////////////////////////////
 /////////////////////////////// PROTECTED ////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
