@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -57,16 +57,14 @@ public:
     ConfigDialog(GlobalObject *globalObject,
                  QString dataDirectory,
                  int updateInterval,
-                 int postsPerPageMain,
-                 int postsPerPageOther,
                  int tabsPosition,
                  bool tabsMovable,
-                 bool publicPosts,
                  FDNotifications *notifier,
                  QWidget *parent);
     ~ConfigDialog();
 
     void syncNotifierOptions();
+    QString checkNotifications(int notificationStyle);
 
 
 signals:
@@ -77,6 +75,7 @@ signals:
 public slots:
     void saveConfiguration();
     void pickCustomIconFile();
+    void showDemoNotification(int notificationStyle);
 
 
 protected:
@@ -140,32 +139,51 @@ private:
     QComboBox *minorFeedSnippetsCombobox;
     QSpinBox *snippetLimitSpinbox;
 
+    QCheckBox *showDeletedCheckbox;
+    QCheckBox *hideDuplicatesCheckbox;
+
 
     // Page 5, posts options
     QWidget *postsOptionsWidget;
     QFormLayout *postsOptionsLayout;
 
+    QComboBox *postAvatarSizeCombobox;
+    QCheckBox *showExtendedSharesCheckbox;
     QCheckBox *showExtraInfoCheckbox;
+    QCheckBox *postHLAuthorCommentsCheckbox;
+    QCheckBox *postHLOwnCommentsCheckbox;
+
+    QCheckBox *postIgnoreSslInImages;
 
 
-    // Page 6, notifications options
+    // Page 6, composer options
+    QWidget *composerOptionsWidget;
+    QFormLayout *composerOptionsLayout;
+
+    QCheckBox *useFilenameAsTitleCheckbox;
+    QCheckBox *showCharacterCounterCheckbox;
+
+
+    // Page 7, notifications options
     QWidget *notificationOptionsWidget;
     QFormLayout *notificationOptionsLayout;
 
     QComboBox *notificationStyleCombobox;
+    QLabel *notificationsStatusLabel;
     QCheckBox *notifyNewTLCheckbox;
     QCheckBox *notifyHLTLCheckbox;
     QCheckBox *notifyNewMWCheckbox;
     QCheckBox *notifyHLMWCheckbox;
 
 
-    // Page 7, system tray options
+    // Page 8, system tray options
     QWidget *systrayOptionsWidget;
     QFormLayout *systrayOptionsLayout;
 
     QComboBox *systrayIconTypeCombobox;
     QPushButton *systrayCustomIconButton;
     QString systrayCustomIconFN;
+    QString systrayIconLastUsedDir;
 
 
     // Widgets below the tab widget
