@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ ContactCard::ContactCard(PumpController *pumpController,
 
 
     // Left widget, user avatar
-    avatarLabel = new QLabel();
+    avatarLabel = new QLabel(this);
 
     this->contactAvatarUrl = asPerson->getAvatar();
 
@@ -88,11 +88,13 @@ ContactCard::ContactCard(PumpController *pumpController,
                               + "</small>");
     }
 
-    userInfoLabel = new QLabel();
+    userInfoLabel = new QLabel(this);
     userInfoLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     userInfoLabel->setText(userInfoString);
     userInfoLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     userInfoLabel->setWordWrap(true);
+    userInfoLabel->setSizePolicy(QSizePolicy::Ignored,
+                                 QSizePolicy::MinimumExpanding);
 
 
     // Bio as tooltip for the whole contact card
@@ -124,7 +126,7 @@ ContactCard::ContactCard(PumpController *pumpController,
 
 
     // Right column, buttons
-    followButton = new QPushButton("*follow*");
+    followButton = new QPushButton("*follow*", this);
     followButton->setFlat(true);    
     if (asPerson->isFollowed())
     {
@@ -136,7 +138,8 @@ ContactCard::ContactCard(PumpController *pumpController,
     }
 
 
-    openProfileAction = new QAction(QIcon::fromTheme("internet-web-browser"),
+    openProfileAction = new QAction(QIcon::fromTheme("internet-web-browser",
+                                                     QIcon(":/images/button-download.png")),
                                     tr("Open Profile in Web Browser"),
                                     this);
     connect(openProfileAction, SIGNAL(triggered()),
@@ -164,7 +167,8 @@ ContactCard::ContactCard(PumpController *pumpController,
 
     optionsButton = new QPushButton(QIcon::fromTheme("user-properties",
                                                      QIcon(":/images/no-avatar.png")),
-                                    tr("User Options"));
+                                    tr("User Options"),
+                                    this);
     optionsButton->setFlat(true);
     optionsButton->setMenu(optionsMenu);
 
@@ -289,8 +293,9 @@ void ContactCard::openProfileInBrowser()
 
 void ContactCard::setMessagingModeForContact()
 {
-    this->globalObj->createMessageForContact(this->contactName,
-                                             this->contactId);
+    this->globalObj->createMessageForContact(this->contactId,
+                                             this->contactName,
+                                             this->contactUrl);
 }
 
 
