@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi JRR <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,21 +31,19 @@ ContactList::ContactList(PumpController *pumpController,
 
     QString filterNote = tr("Type a partial name or ID to find a contact...")
                          + " (Control+F)";
-    this->filterLineEdit = new QLineEdit();
+    this->filterLineEdit = new QLineEdit(this);
     filterLineEdit->setPlaceholderText(filterNote);
     filterLineEdit->setToolTip("<b></b>" + filterNote); // HTMLized for wordwrapping
     connect(filterLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(filterList(QString)));
 
     this->removeFilterButton = new QPushButton(QIcon::fromTheme("view-list-icons"),
-                                               tr("F&ull List"));
+                                               tr("F&ull List"),
+                                               this);
     removeFilterButton->setDisabled(true); // Disabled initially, until a search happens
     connect(removeFilterButton, SIGNAL(clicked()),
             filterLineEdit, SLOT(clear()));
 
-    this->filterLayout = new QHBoxLayout();
-    filterLayout->addWidget(filterLineEdit);
-    filterLayout->addWidget(removeFilterButton);
 
     goToFilterAction = new QAction(this);
     goToFilterAction->setShortcut(QKeySequence("Ctrl+F"));
@@ -54,13 +52,17 @@ ContactList::ContactList(PumpController *pumpController,
     this->addAction(goToFilterAction);
 
 
-    this->contactsLayout = new QVBoxLayout();
-    contactsLayout->setAlignment(Qt::AlignTop);
+    // Layout
+    this->filterLayout = new QHBoxLayout();
+    filterLayout->addWidget(filterLineEdit);
+    filterLayout->addWidget(removeFilterButton);
 
-    this->contactsWidget = new QWidget();
+    this->contactsLayout = new QVBoxLayout();
+
+    this->contactsWidget = new QWidget(this);
     contactsWidget->setLayout(contactsLayout);
 
-    this->contactsScrollArea = new QScrollArea();
+    this->contactsScrollArea = new QScrollArea(this);
     contactsScrollArea->setWidget(contactsWidget);
     contactsScrollArea->setWidgetResizable(true);
     contactsScrollArea->setFrameStyle(QFrame::NoFrame);
@@ -78,16 +80,21 @@ ContactList::ContactList(PumpController *pumpController,
     QVariantMap demoContactHometown;
     QVariantMap demoContactFollowed;
 
+    this->isFollowing = false;
     if (listType == "following")
     {
+        isFollowing = true;
+
         demoContactData.insert("displayName",  "Demo Contact");
         demoContactData.insert("id",           "democontact@pumpserver.org");
+        demoContactData.insert("url",          "http://jancoding.wordpress.com");
         demoContactFollowed.insert("followed", "true");
     }
     else
     {
         demoContactData.insert("displayName",  "Demo Follower");
         demoContactData.insert("id",           "demofollower@pumpserver.org");
+        demoContactData.insert("url",          "http://dianara.nongnu.org");
         demoContactFollowed.insert("followed", "false");
     }
 
@@ -126,12 +133,16 @@ void ContactList::clearListContents()
     }
     this->contactsInList.clear();
 
-    this->contactsListString.clear();
+    this->contactsStringForExport.clear();
+
+    if (this->isFollowing)
+    {
+        this->globalObj->clearNickCompletionModel();
+    }
 }
 
 
-void ContactList::setListContents(QString listType,
-                                  QVariantList contactList)
+void ContactList::setListContents(QVariantList contactList)
 {
     qDebug() << "ContactList; Setting list contents";
 
@@ -144,27 +155,34 @@ void ContactList::setListContents(QString listType,
         ContactCard *contactCard = new ContactCard(this->pController,
                                                    this->globalObj,
                                                    person, this);
+        this->contactsLayout->addWidget(contactCard);
+        this->contactsInList.append(contactCard);
 
+        // Info for the string list used when exporting
         contactInfoLineString = person->getName()
                               + "  <"
                               + person->getId()
                               + ">\n";
+        contactsStringForExport.append(contactInfoLineString);
 
-        this->contactsLayout->addWidget(contactCard);
-        this->contactsInList.append(contactCard);
-        contactsListString.append(contactInfoLineString);
-
-        if (listType == "following")
+        if (this->isFollowing)
         {
+            // Add to internal following list for PumpController
             followingIdStringList.append(person->getId());
+
+            // Add also to GlobalObject's model for nick completion
+            this->globalObj->addToNickCompletionModel(person->getId(),
+                                                      person->getNameWithFallback(),
+                                                      person->getUrl());
         }
-    }
+    } // end foreach
 
 
     // Batch of contacts added to list, add them also to the internal list
-    if (listType == "following")
+    if (this->isFollowing)
     {
         this->pController->updateInternalFollowingIdList(followingIdStringList);
+        this->globalObj->sortNickCompletionModel(); // FIXME: should only sort when the whole list is done
     }
 
     this->filterLineEdit->clear(); // Unfilter the list
@@ -172,15 +190,9 @@ void ContactList::setListContents(QString listType,
 
 
 
-void ContactList::adjustWidth()
+QString ContactList::getContactsStringForExport()
 {
-    this->contactsWidget->setMaximumWidth(this->contactsScrollArea->viewport()->width());
-}
-
-
-QString ContactList::getContactsListString()
-{
-    return this->contactsListString;
+    return this->contactsStringForExport;
 }
 
 
@@ -234,9 +246,18 @@ void ContactList::addSingleContact(ASPerson *contact)
 
     emit contactCountChanged(1);
 
-    QStringList contactsToAdd;
-    contactsToAdd.append(contact->getId());
-    this->pController->updateInternalFollowingIdList(contactsToAdd);
+    // This check is actually unnecessary, since this slot is only called
+    if (this->isFollowing) // for the 'following' list
+    {
+        QStringList contactsToAdd;
+        contactsToAdd.append(contact->getId());
+        this->pController->updateInternalFollowingIdList(contactsToAdd);
+
+        // Add also to GlobalObject's model for nick completion
+        this->globalObj->addToNickCompletionModel(contact->getId(),
+                                                  contact->getNameWithFallback(),
+                                                  contact->getUrl());
+    }
 }
 
 
@@ -250,31 +271,12 @@ void ContactList::removeSingleContact(ASPerson *contact)
 
             this->pController->removeFromInternalFollowingList(contact->getId());
 
+            // Remove from GlobalObject's model for nick completion, too
+            this->globalObj->removeFromNickCompletionModel(contact->getId());
+
             card->setDisabled(true);
         }
     }
 
     contact->deleteLater();
 }
-
-
-
-/*****************************************************************************/
-/********************************* PROTECTED *********************************/
-/*****************************************************************************/
-
-
-
-void ContactList::resizeEvent(QResizeEvent *event)
-{
-    this->adjustWidth();
-
-    event->accept();
-}
-
-void ContactList::showEvent(QShowEvent *event)
-{
-    this->adjustWidth();
-
-    event->accept();
-}
