@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -223,11 +223,11 @@ void ContactManager::exportContactsToFile(QString listType)
 
     if (listType == "following")
     {
-        exportFile.write(this->followingWidget->getContactsListString().toLocal8Bit());
+        exportFile.write(this->followingWidget->getContactsStringForExport().toLocal8Bit());
     }
     else // "followers"
     {
-        exportFile.write(this->followersWidget->getContactsListString().toLocal8Bit());
+        exportFile.write(this->followersWidget->getContactsStringForExport().toLocal8Bit());
     }
     exportFile.close();
 }
@@ -254,8 +254,7 @@ void ContactManager::setContactListsContents(QString listType,
             this->followingWidget->clearListContents();
             followingCount = 0;
         }
-        followingWidget->setListContents(listType,
-                                         contactList);
+        followingWidget->setListContents(contactList);
 
         if (totalReceivedCount < pController->currentFollowingCount())
         {
@@ -271,8 +270,7 @@ void ContactManager::setContactListsContents(QString listType,
             this->followersWidget->clearListContents();
             followersCount = 0;
         }
-        followersWidget->setListContents(listType,
-                                         contactList);
+        followersWidget->setListContents(contactList);
 
         if (totalReceivedCount < pController->currentFollowersCount())
         {
@@ -417,6 +415,7 @@ void ContactManager::followContact()
         {
             QStringList addressParts = address.split("/");
             address = addressParts.at(1) + "@" + addressParts.at(0);
+            // .at(2) could also have stuff, so don't use .first() and .last()
 
             validAddress = true;
         }
