@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -54,11 +54,16 @@ void HClabel::setHighlighted(bool highlighted)
     {
         // Constant highlighting
         this->setStyleSheet("QLabel "
-                            "{ color: palette(highlighted-text);   "
-                            "  background-color: palette(highlight)"
+                            "{ color: palette(highlighted-text);               "
+                            "  background-color: qlineargradient(spread:pad,   "
+                            "                     x1:0, y1:0, x2:0, y2:1,      "
+                            "                     stop:0   rgba(0, 0, 0, 0),   "
+                            "                     stop:0.3 palette(highlight), "
+                            "                     stop:0.7 palette(highlight), "
+                            "                     stop:1   rgba(0, 0, 0, 0));  "
                             "}"
                             "QLabel:hover "
-                            "{ color: palette(text);               "
+                            "{ color: palette(highlighted-text);   "
                             "  background-color: palette(highlight)"
                             "}");
     }
@@ -68,7 +73,9 @@ void HClabel::setHighlighted(bool highlighted)
         this->setStyleSheet("QLabel "
                             "{ background-color: transparent }"
                             "QLabel:hover "
-                            "{ background-color: palette(highlight) }");
+                            "{ color: palette(highlighted-text);   "
+                            "  background-color: palette(highlight)"
+                            "}");
     }
 }
 
