@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi JRR <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -180,6 +180,14 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                     + tr("If you add a specific person to the 'To' list, they "
                          "will receive your message in their direct messages tab.")
                     + "<br>");
+    helpText.append(tr("You can also type '@' and the first characters of the "
+                       "name of a contact to bring up a popup menu with "
+                       "matching choices.")
+                    + " "
+                    + tr("Choose one with the arrow keys and press Enter to "
+                         "complete the name. This will add that person to the "
+                         "recipients list.")
+                    + "<br><br>");
     helpText.append(tr("You can create private messages by adding specific "
                        "people to these lists, and unselecting the Followers "
                        "or the Public options."));
@@ -195,20 +203,27 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                     + " "
                     + tr("There, you can also manage person lists, used mainly "
                          "to send posts to specific groups of people.")
-                    + "<br>"
+                    + " "
+                    + tr("There is a text field at the top, where you can "
+                         "directly enter addresses of new contacts to "
+                         "follow them.")
+                    + "<br><br>"
                     + tr("You can click on any avatars in the posts, the "
                          "comments, and the Meanwhile column, and you will get "
                          "a menu with several options, one of which is following "
                          "or unfollowing that person.")
                     + " "
-                    + tr("You can also send a direct message (initially private) "
-                         "to that contact from this menu.")
+                    + tr("You can also send a direct message (initially "
+                         "private) to that contact from this menu.")
                     + "<br><br>");
     helpText.append(tr("You can find a list with some Pump.io users "
                        "and other information here:")
-                    + " <a href=\"https://static.jpope.org/users.html\">"
-                      "static.jpope.org/users.html"
-                      "</a>");
+                    + "<br>"
+                      "<a href=\"https://static.jpope.org/users.html\">"
+                      "static.jpope.org/users.html</a> - "
+                      "<a href=\"https://github.com/e14n/pump.io/wiki/Users-by-language\">"
+                    + tr("Users by language")
+                    + "</a>");
 
 
     helpText.append("<br><hr>");
@@ -243,6 +258,9 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                          "title to the message body. Also, pressing the Up "
                          "arrow while you're at the start of the message, jumps "
                          "back to the title.") + "</li>"
+                    + "<li>"
+                    + tr("Control+Enter to finish creating a list of recipients "
+                         "for a post, in the 'To' or 'Cc' lists.") + "</li>"
                     + "</ul>");
 
 
@@ -311,7 +329,10 @@ void HelpWidget::closeEvent(QCloseEvent *event)
 void HelpWidget::hideEvent(QHideEvent *event)
 {
     QSettings settings;
-    settings.setValue("HelpWidget/helpWindowSize", this->size());
+    if (settings.isWritable())
+    {
+        settings.setValue("HelpWidget/helpWindowSize", this->size());
+    }
 
     event->accept();
 }
