@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -98,8 +98,8 @@ ListsManager::ListsManager(PumpController *pumpController,
                                           PeopleWidget::StandaloneWidget,
                                           this->pController,
                                           this);
-    connect(peopleWidget, SIGNAL(addButtonPressed(QIcon,QString)),
-            this, SLOT(addPerson(QIcon,QString)));
+    connect(peopleWidget, SIGNAL(addButtonPressed(QIcon,QString,QString)),
+            this, SLOT(addPerson(QIcon,QString,QString)));
 
 
     // Layout
@@ -142,6 +142,9 @@ void ListsManager::setListsList(QVariantList listsList)
 {
     qDebug() << "Setting person lists contents";
 
+    // Disable to avoid users messing with it while it loads
+    this->setDisabled(true);
+
     this->listsTreeWidget->clear();
     this->personListsUrlList.clear();
 
@@ -149,6 +152,7 @@ void ListsManager::setListsList(QVariantList listsList)
     QString listDescription;
     QString listMembersCount;
     QVariant listId;
+    QVariant listUrl;
 
     foreach (QVariant list, listsList)
     {
@@ -160,9 +164,13 @@ void ListsManager::setListsList(QVariantList listsList)
             listDescription.prepend("<b></b>"); // HTMLize it so it gets wordwrapped
         }
 
-        listMembersCount = listMap.value("members").toMap().value("totalItems").toString();
+        listMembersCount = listMap.value("members").toMap()
+                                  .value("totalItems").toString();
         listId = listMap.value("id");
+        listUrl = listMap.value("members").toMap().value("url");
         qDebug() << "list ID:" << listId.toString();
+        qDebug() << "list URL:" << listUrl.toString();
+
 
         QTreeWidgetItem *listItem = new QTreeWidgetItem();
         listItem->setText(0, listName);
@@ -170,11 +178,13 @@ void ListsManager::setListsList(QVariantList listsList)
         listItem->setText(1, listMembersCount);
         listItem->setToolTip(1, listDescription);
         listItem->setData(0, Qt::UserRole, listId);
+        listItem->setData(0, Qt::UserRole + 1, listUrl);
 
 
         this->listsTreeWidget->addTopLevelItem(listItem);
 
-        QString membersUrl = listMap.value("members").toMap().value("url").toString();
+        QString membersUrl = listMap.value("members").toMap()
+                                    .value("url").toString();
         this->personListsUrlList.append(membersUrl);
     }
 
@@ -187,6 +197,9 @@ void ListsManager::setListsList(QVariantList listsList)
 
     // this->listsTreeWidget->expandAll();
     this->listsTreeWidget->resizeColumnToContents(0);
+
+    // Re-enable
+    this->setEnabled(true);
 }
 
 
@@ -229,16 +242,14 @@ void ListsManager::setPersonsInList(QVariantList personList, QString listUrl)
 {
     qDebug() << "ListsManager::setPersonsInList()" << listUrl;
 
-    QString listId = listUrl.split("/members").at(0);
-    qDebug() << "List ID:" << listId;
-
     // Find out which TreeWidgetItem matches this list
     QTreeWidgetItem  *listItem = 0; // Avoid 'not initialized' warning
     foreach (QTreeWidgetItem *item, this->listsTreeWidget->findItems("", Qt::MatchContains))
     {
         listItem = item;
 
-        if (listItem->data(0, Qt::UserRole).toString() == listId)
+        // Data in UserRole+1 is the Members Url
+        if (listItem->data(0, Qt::UserRole + 1).toString() == listUrl)
         {
             break;
         }
@@ -304,7 +315,8 @@ void ListsManager::deleteList()
         // Avoid the possibility of deleting twice!
         this->deleteListButton->setDisabled(true);
 
-        QString listId = this->listsTreeWidget->currentItem()->data(0, Qt::UserRole).toString();
+        QString listId = this->listsTreeWidget->currentItem()->data(0,
+                                                                    Qt::UserRole).toString();
 
         this->pController->deletePersonList(listId);
     }
@@ -371,9 +383,11 @@ void ListsManager::showAddPersonDialog()
 }
 
 
-void ListsManager::addPerson(QIcon icon, QString contactString)
+void ListsManager::addPerson(QIcon icon, QString contactString,
+                             QString contactUrl)
 {
     Q_UNUSED(icon)
+    Q_UNUSED(contactUrl)
     this->peopleWidget->hide();
 
 
@@ -441,11 +455,12 @@ void ListsManager::removePerson()
     }
     else
     {
-        qDebug() << "Confirmation canceled, not removing" << personName << "from" << listName;
+        qDebug() << "Confirmation canceled, not removing" << personName
+                 << "from" << listName;
     }
-
 }
 
+
 /*
  * Add the new item itself after a person is added correctly in PumpController
  *
