@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -44,19 +44,21 @@ LogViewer::LogViewer(QWidget *parent) : QWidget(parent)
     this->addAction(closeAction);
 
 
-    logTextBrowser = new QTextBrowser();
+    logTextBrowser = new QTextBrowser(this);
     logTextBrowser->setReadOnly(true);
     logTextBrowser->setOpenExternalLinks(true);
 
 
     clearButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
                                                    QIcon(":/images/button-delete.png")),
-                                  tr("Clear &Log"));
+                                  tr("Clear &Log"),
+                                  this);
     connect(clearButton, SIGNAL(clicked()),
             logTextBrowser, SLOT(clear()));
 
     closeButton = new QPushButton(QIcon::fromTheme("window-close"),
-                                  tr("&Close"));
+                                  tr("&Close"),
+                                  this);
     connect(closeButton, SIGNAL(clicked()),
             this, SLOT(hide()));
 
@@ -92,7 +94,10 @@ void LogViewer::closeEvent(QCloseEvent *event)
 void LogViewer::hideEvent(QHideEvent *event)
 {
     QSettings settings;
-    settings.setValue("LogViewer/logWindowSize", this->size());
+    if (settings.isWritable())
+    {
+        settings.setValue("LogViewer/logWindowSize", this->size());
+    }
 
     event->accept();
 }
@@ -137,3 +142,16 @@ void LogViewer::addToLog(QString message, QString url)
 
     logTextBrowser->append(logLine);
 }
+
+
+void LogViewer::toggleVisibility()
+{
+    if (this->isVisible())
+    {
+        this->hide();
+    }
+    else
+    {
+        this->show();
+    }
+}
