@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -56,14 +56,18 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.2.5");
+    dianaraApp.setApplicationVersion("1.3.0");
     dianaraApp.setOrganizationName("JanCoding");
     dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
 
-    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2014\n")
+    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2015\n"
+                         "http://jancoding.wordpress.com/dianara\n\n")
                         .arg(dianaraApp.applicationVersion()).toStdString();
-    std::cout << QString("- Built with Qt v%1\n").arg(QT_VERSION_STR).toStdString();
-    //  ... + ("on %2, %3").arg(__DATE__).arg(__TIME__)
+    std::cout << QString("- Built with Qt v%1 on %2, %3\n")
+                 .arg(QT_VERSION_STR)
+                 .arg(__DATE__)
+                 .arg(__TIME__).toStdString();
+
     std::cout << QString("- Running with Qt v%1\n\n").arg(qVersion()).toStdString();
     std::cout.flush();
 
@@ -78,6 +82,7 @@ int main(int argc, char *argv[])
 
     bool debugMode = false;
     bool nextParameterIsConfig = false;
+    bool ignoreSslErrors = false;
 
     // Parse command line parameters
     if (!cmdLine.isEmpty())
@@ -85,20 +90,37 @@ int main(int argc, char *argv[])
         foreach (QString argument, cmdLine)
         {
             // Help
-            if (argument.startsWith("--help", Qt::CaseInsensitive))
+            if (argument.startsWith("--help", Qt::CaseInsensitive)
+             || argument.startsWith("-h", Qt::CaseInsensitive))
             {
                 std::cout << "\nHelp:\n";
                 std::cout << "    " << argv[0] << " [options]\n\n";
                 std::cout << "Options:\n";
-                std::cout << "    --debug           Show debug messages in the terminal\n";
-                std::cout << "    --config [name]   Use a different configuration file\n";
+                std::cout << "    -c  --config [name]   Use a different "
+                             "configuration file\n";
+                std::cout << "    -d  --debug           Show debug messages "
+                             "in the terminal\n";
+                std::cout << "        --ignoresslerrors Ignore SSL errors "
+                             "(dangerous, use with care!)\n";
+                std::cout << "    -v  --version         Show version "
+                             "information and exit\n";
+                std::cout << "    -h  --help            Show this help and "
+                             "exit\n";
                 std::cout << "\n";
 
                 return 0; // Exit to shell
             }
 
+            if (argument.startsWith("--version", Qt::CaseInsensitive)
+             || argument.startsWith("-v", Qt::CaseInsensitive))
+            {
+                return 0;
+            }
+
+
             // Use different config file, by setting a different applicationName
-            if (argument.startsWith("--config", Qt::CaseInsensitive))
+            if (argument.startsWith("--config", Qt::CaseInsensitive)
+             || argument.startsWith("-c", Qt::CaseInsensitive))
             {
                 nextParameterIsConfig = true;
                 cmdLine.removeAll(argument);
@@ -114,13 +136,26 @@ int main(int argc, char *argv[])
             }
 
             // Debug mode
-            if (argument.startsWith("--debug", Qt::CaseInsensitive))
+            if (argument.startsWith("--debug", Qt::CaseInsensitive)
+             || argument.startsWith("-d", Qt::CaseInsensitive))
             {
                 debugMode = true;
                 cmdLine.removeAll(argument);
 
                 std::cout << "Debug messages enabled\n";
             }
+
+            // Option to ignore SSL errors
+            if (argument.startsWith("--ignoresslerrors", Qt::CaseInsensitive))
+            {
+                ignoreSslErrors = true;
+                cmdLine.removeAll(argument);
+
+                std::cout << "*************************************\n"
+                             "*** WARNING: Ignoring SSL errors. ***\n"
+                             "***          This is insecure!    ***\n"
+                             "*************************************\n";
+            }            
         }
     }
 
@@ -163,6 +198,11 @@ int main(int argc, char *argv[])
 
 
     MainWindow dianaraWindow;
+    if (ignoreSslErrors)
+    {
+        dianaraWindow.enableIgnoringSslErrors();
+    }
+
     dianaraWindow.toggleMainWindow();  // show()
 
 
