@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -50,6 +50,7 @@
 #include <QTime>
 #include <QSplitter>
 #include <QPainter>
+#include <QSessionManager>
 
 #include <QDebug>
 
@@ -85,6 +86,7 @@ public:
     void prepareDataDirectory();
     void createMenus();
     void createToolbar();
+    virtual QMenu *createPopupMenu();
     void createStatusbarWidgets();
 
     enum StatusType
@@ -96,11 +98,18 @@ public:
 
     void setStateIcon(StatusType statusType);
     void createTrayIcon();
-    void setTrayIconPixmap(int newCount = 0, int hightlightedCount = 0);
+    void setTrayIconPixmap(int newCount = 0, int highlightedCount = 0);
 
     void loadSettings();
     void saveSettings();
 
+    void enableIgnoringSslErrors();
+
+    Post *findPostInTimelines(QString id, bool *ok);
+
+    void loadPostsEverSeen();
+    void savePostsEverSeen();
+
 
 public slots:
     void updateUserID(QString newUserID);
@@ -122,8 +131,10 @@ public slots:
     void toggleAutoUpdates(bool checked);
 
     void updateAllTimelines();
-    void updateMainDirectMinorTimelines();
+    void updateMainAndMinorTimelines();
     void updateMainActivityMinorTimelines();
+    void updateFavoritesTimeline();
+    void updateActionsFeed();
 
     void scrollMainTimelineTo(QAbstractSlider::SliderAction sliderAction);
     void scrollDirectTimelineTo(QAbstractSlider::SliderAction sliderAction);
@@ -135,22 +146,27 @@ public slots:
     void scrollActivityTimelineToWidget(QWidget *widget);
     void scrollFavoritesTimelineToWidget(QWidget *widget);
 
-    void notifyTimelineUpdate(int timelineType,
-                              int newPostCount,
-                              int highlightCount);
-    void setTimelineTabTitle(int timelineType,
+    void notifyTimelineUpdate(PumpController::requestTypes timelineType,
+                              int newPostCount, int highlightCount,
+                              int deletedPostCount, int filteredPostCount,
+                              int pendingPostCount);
+    void setTimelineTabTitle(PumpController::requestTypes timelineType,
                              int newPostCount,
                              int highlightCount,
-                             int totalItemsCount);
+                             int totalFeedPostCount);
 
     void setTitleAndTrayInfo(int currentTab);
     void setMinorFeedTitle(int newItemsCount, int newHighlightedItemsCount);
     void setMentionsFeedTitle(int newItemsCount, int newHighlightedItemsCount);
-    void notifyMinorFeedUpdate(int newItemsCount, int highlightedCount);
-    void notifyMentionsFeedUpdate(int newItemsCount, int highlightedCount);
+    void notifyMinorFeedUpdate(PumpController::requestTypes feedType,
+                               int newItemsCount,
+                               int highlightedCount,
+                               int filteredCount,
+                               int pendingItemsCount);
 
-    void storeAvatar(QByteArray avatarData, QUrl avatarUrl);
-    void storeImage(QByteArray imageData, QUrl imageUrl);
+
+    void storeAvatar(QByteArray avatarData, QString avatarUrl);
+    void storeImage(QByteArray imageData, QString imageUrl);
 
     void setStatusBarMessage(QString message);
     void setTransientStatusMessage(QString message);
@@ -181,7 +197,8 @@ public slots:
 
     void showAuthError(QString title, QString message);
 
-    void quitProgram();
+    void onSessionManagerQuitRequest(QSessionManager &manager);
+    void quitProgram(QString reason="");
 
 
 protected:
@@ -232,6 +249,11 @@ private:
     QAction *helpAbout;
     ////////////////////////////////////// End menus
 
+    // Info label for the menu
+    QHBoxLayout *menuInfoLayout;
+    QWidget *menuInfoWidget;
+    QLabel *menuInfoLabel;
+
     // Toolbar
     QToolBar *mainToolBar;
 
@@ -291,11 +313,9 @@ private:
     MinorFeed *mentionsFeed;
     MinorFeed *actionsFeed;
 
-    int postsPerPageMain;
     TimeLine *mainTimeline;
     QScrollArea *mainTimelineScrollArea;
 
-    int postsPerPageOther;
     TimeLine *directTimeline;
     QScrollArea *directTimelineScrollArea;
 
@@ -321,13 +341,13 @@ private:
 
     QTimer *timestampsTimer;
     QTimer *delayedResizeTimer;
-
     QTimer *postInitTimer;
-
-    bool publicPosts;
+    QTimer *favoritesReloadTimer;
+    QTimer *userDidSomethingTimer;
 
     QString oldStatusBarMessage;
-    QString previousStatusMessageForMinorFeed;
+    QString previousStatusMessageFromTimeline;
+    QString previousStatusMessageFromMinorFeed;
 
     // user account-related data
     QString userID;
