@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -40,6 +40,9 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     activity->setParent(this); // reparent the passed activity
 
+    // Store activity ID so MinorFeed can reconstruct "next" url's
+    this->activityId = activity->getId();
+
     QFont mainFont;
     mainFont.setPointSize(mainFont.pointSize() - 2);
 
@@ -88,7 +91,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
         }
     }
 
-    timestampLabel = new QLabel();
+    timestampLabel = new QLabel(this);
     mainFont.setBold(true);
     timestampLabel->setFont(mainFont);
     timestampLabel->setWordWrap(true);
@@ -102,7 +105,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
 
     // The description itself, like "JaneDoe updated a note",
-    activityDescriptionLabel = new QLabel(); // To be filled later
+    activityDescriptionLabel = new QLabel(this); // To be filled later
     QFont descriptionFont;
     descriptionFont.fromString(globalObj->getMinorFeedFont());
     activityDescriptionLabel->setWordWrap(true);
@@ -136,62 +139,41 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     // Highlight this item if it's about the user, with different colors
     itemHighlightType = -1; // False
-    QStringList highlightColors = globalObj->getColorsList();
     QString highlightItemColor;
 
     // We are in the recipient list of the activity
     if (activity->getRecipientsIdList().contains("acct:" + pController->currentUserId()))
     {
         itemHighlightType = 0;
-
-        if (QColor::isValidColor(highlightColors.at(itemHighlightType)))
-        {
-            highlightItemColor = highlightColors.at(itemHighlightType);
-        }
+        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     // Activity is in reply to something made by us
     if (inReplyToAuthorId == pController->currentUserId())
     {
         itemHighlightType = 1;
-
-        if (QColor::isValidColor(highlightColors.at(itemHighlightType)))
-        {
-            highlightItemColor = highlightColors.at(itemHighlightType);
-        }
+        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     // We are the object; someone added us, etc.
     if (activity->object()->getId() == pController->currentUserId())
     {
         itemHighlightType = 2;
-
-        if (QColor::isValidColor(highlightColors.at(itemHighlightType)))
-        {
-            highlightItemColor = highlightColors.at(itemHighlightType);
-        }
+        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     // The object is ours; someone favorited our note, or something
     if (activity->object()->author()->getId() == pController->currentUserId())
     {
         itemHighlightType = 3;
-
-        if (QColor::isValidColor(highlightColors.at(itemHighlightType)))
-        {
-            highlightItemColor = highlightColors.at(itemHighlightType);
-        }
+        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
     //// Special case: highlighting the item because there's a filter rule for it
     if (highlightedByFilter && itemHighlightType == -1) // Only if there's no other reason for HL
     {
         itemHighlightType = 4;
-
-        if (QColor::isValidColor(highlightColors.at(itemHighlightType)))
-        {
-            highlightItemColor = highlightColors.at(itemHighlightType);
-        }
+        highlightItemColor = this->globalObj->getColor(itemHighlightType);
     }
 
 
@@ -252,10 +234,13 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
 
 
-    ////// Layout
+    //////////////////////////////////////////////////////// Layout
     leftLayout = new QVBoxLayout();
     leftLayout->setAlignment(Qt::AlignTop);
-    leftLayout->addWidget(avatarButton, 1, Qt::AlignTop | Qt::AlignLeft);
+    leftLayout->setContentsMargins(1, 0, 1, 0);
+    leftLayout->setSpacing(1);
+    leftLayout->addWidget(avatarButton, 0, Qt::AlignTop | Qt::AlignLeft);
+    leftLayout->addStretch(0);
 
 
 
@@ -268,7 +253,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
         this->openButton = new QPushButton("+");
         openButton->setSizePolicy(QSizePolicy::Ignored,
                                   QSizePolicy::Maximum);
-        openButton->setToolTip(tr("Open referenced post"));
+        openButton->setToolTip("<b></b>"
+                               + tr("Open referenced post"));
         connect(openButton, SIGNAL(clicked()),
                 this, SLOT(openOriginalPost()));
         leftLayout->addWidget(openButton, 0, Qt::AlignHCenter);
@@ -303,6 +289,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
 
     mainLayout = new QHBoxLayout();
+    mainLayout->setContentsMargins(2, 1, 2, 4);
     if (authorId == pController->currentUserId())
     {
         mainLayout->addLayout(rightLayout, 10);
@@ -330,7 +317,7 @@ MinorFeedItem::~MinorFeedItem()
  * Pseudo-highlight for new items
  *
  */
-void MinorFeedItem::setItemAsNew(bool isNew)
+void MinorFeedItem::setItemAsNew(bool isNew, bool informFeed)
 {
     itemIsNew = isNew;
 
@@ -340,11 +327,15 @@ void MinorFeedItem::setItemAsNew(bool isNew)
         this->setBackgroundRole(QPalette::Mid);
 
         timestampLabel->setStyleSheet("QLabel "
-                                      "{ color: palette(highlighted-text);   "
-                                      "  background-color: palette(highlight)"
+                                      "{ background-color: qlineargradient(spread:pad,"
+                                      "                    x1:0, y1:0, x2:1, y2:0,"
+                                      "                    stop:0   palette(highlight),"
+                                      "                    stop:0.2 palette(base),"
+                                      "                    stop:0.8 palette(base),"
+                                      "                    stop:1   palette(highlight));"
                                       "}"
                                       "QLabel:hover "
-                                      "{ color: palette(text);               "
+                                      "{ color: palette(highlighted-text);   "
                                       "  background-color: palette(highlight)"
                                       "}");
     }
@@ -354,18 +345,26 @@ void MinorFeedItem::setItemAsNew(bool isNew)
         this->setBackgroundRole(QPalette::Window);
 
         timestampLabel->setStyleSheet("QLabel:hover "
-                                      "{ background-color: palette(highlight) }");
-        bool wasHighlighted = false;
-        if (this->itemHighlightType != -1)
-        {
-            wasHighlighted = true;
-        }
-        emit itemRead(wasHighlighted);
-    }
+                                      "{ color: palette(highlighted-text);   "
+                                      "  background-color: palette(highlight)"
+                                      "}");
 
-    // Avoid possible flickering of the "new" effect later
-    this->timestampLabel->update();
-    this->update();
+        if (informFeed)
+        {
+            bool wasHighlighted = false;
+            if (this->itemHighlightType != -1)
+            {
+                wasHighlighted = true;
+            }
+
+            emit itemRead(wasHighlighted);
+        }
+    }
+}
+
+bool MinorFeedItem::isNew()
+{
+    return this->itemIsNew;
 }
 
 
@@ -395,6 +394,11 @@ int MinorFeedItem::getItemHighlightType()
     return this->itemHighlightType;
 }
 
+QString MinorFeedItem::getActivityId()
+{
+    return this->activityId;
+}
+
 
 
 /****************************************************************************/
@@ -410,12 +414,14 @@ void MinorFeedItem::openOriginalPost()
     if (!inReplyToMap.isEmpty())
     {
         originalPostMap.insert("object", this->inReplyToMap);
-        originalPostMap.insert("actor", this->inReplyToMap.value("author").toMap());
+        originalPostMap.insert("actor",
+                               this->inReplyToMap.value("author").toMap());
     }
     else
     {
         originalPostMap.insert("object", this->originalObjectMap);
-        originalPostMap.insert("actor", this->originalObjectMap.value("author").toMap());
+        originalPostMap.insert("actor",
+                               this->originalObjectMap.value("author").toMap());
     }
 
     ASActivity *originalPostActivity = new ASActivity(originalPostMap, this);
@@ -463,7 +469,11 @@ void MinorFeedItem::mousePressEvent(QMouseEvent *event)
 {
     if (itemIsNew)
     {
-        this->setItemAsNew(false);
+        this->setItemAsNew(false, // Mark as not new
+                           true); // Inform the feed
+
+        // Avoid flickering of the "new" effect later
+        this->timestampLabel->repaint();
     }
 
     event->accept();
