@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -148,6 +148,7 @@ void FDNotifications::showMessage(QString message)
         message.remove("</i>");
         message.remove("<u>");
         message.remove("</u>");
+        message.replace("<br>", "\n");
         // FIXME: remove also <a href=...>
         emit showFallbackNotification(notificationTitle, message);
 
@@ -158,6 +159,8 @@ void FDNotifications::showMessage(QString message)
     // Only when building with DBus support
 #ifdef QT_DBUS_LIB
     message.replace("\n", "<br>"); // use HTML newlines
+    // HTML newlines break notifications in Xfce; \n works, but is not actually
+    // shown as newline in Plasma 4's notifications
 
     QDBusMessage dBusMessage = QDBusMessage::createMethodCall(
                                  "org.freedesktop.Notifications",
