@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,38 +24,42 @@
 PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
 {
     this->setWindowTitle(tr("Jump to page") + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("go-next-view-page"));
-
+    this->setWindowIcon(QIcon::fromTheme("go-next-view-page",
+                                         QIcon(":/images/button-next.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
 
 
-    this->messageLabel = new QLabel(tr("Page number:"));
+    this->messageLabel = new QLabel(tr("Page number:"),
+                                    this);
 
-    this->pageNumberSpinbox = new QSpinBox();
+    this->pageNumberSpinbox = new QSpinBox(this);
     pageNumberSpinbox->setRange(1, 1); // 1-totalPages, but initially 1-1
     pageNumberSpinbox->setValue(1);
     connect(pageNumberSpinbox, SIGNAL(editingFinished()),
             this, SLOT(onPageNumberEntered()));
 
-    this->rangeLabel = new QLabel();
+    this->rangeLabel = new QLabel(this);
 
     this->goButton = new QPushButton(QIcon::fromTheme("go-next-view-page",
-                                                      QIcon(":/images/button-share.png")),
-                                     tr("&Go"));
+                                                      QIcon(":/images/button-next.png")),
+                                     tr("&Go") + " >>",
+                                     this);
     connect(goButton, SIGNAL(clicked()),
             this, SLOT(goToPage()));
 
     this->goToLastButton = new QPushButton(QIcon::fromTheme("go-last-view-page",
-                                                            QIcon(":/images/button-share.png")),
-                                           tr("Go to &last page"));
+                                                            QIcon(":/images/button-next.png")),
+                                           tr("Go to &last page"),
+                                           this);
     connect(goToLastButton, SIGNAL(clicked()),
             this, SLOT(goToLastPage()));
 
 
     this->closeButton = new QPushButton(QIcon::fromTheme("window-close",
                                                          QIcon(":/images/button-cancel.png")),
-                                        tr("&Cancel"));
+                                        tr("&Cancel"),
+                                        this);
     connect(closeButton, SIGNAL(clicked()),
             this, SLOT(hide()));
 
@@ -71,22 +75,22 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     this->topLayout = new QHBoxLayout();
     topLayout->addWidget(messageLabel);
     topLayout->addWidget(pageNumberSpinbox);
-    topLayout->addSpacing(8);
+    topLayout->addSpacing(4);
     topLayout->addWidget(rangeLabel);
-    topLayout->addSpacing(24);
-    topLayout->addWidget(goButton);
+    topLayout->addSpacing(8);
+    topLayout->addWidget(goButton, 1);
 
     this->bottomLayout = new QHBoxLayout();
     bottomLayout->addWidget(goToLastButton);
-    bottomLayout->addSpacing(8);
+    bottomLayout->addSpacing(16);
     bottomLayout->addWidget(closeButton);
 
 
     this->mainLayout = new QVBoxLayout();
     mainLayout->addLayout(topLayout);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(22);
     mainLayout->addStretch(1);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(22);
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
