@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -66,8 +66,11 @@ public:
          QWidget *parent);
     ~Post();
 
+    void updateDataFromActivity(ASActivity *activity);
+    void updateDataFromObject(ASObject *object);
 
-    void setMinMaxHeight(int newMinMaxHeight);
+    void updateCommentFromObject(ASObject *object);
+    void setCommentDeletedFromObject(ASObject *object);
 
     void setPostContents();
     void onResizeOrShow();
@@ -75,12 +78,16 @@ public:
     void resetResizesCount();
     void getPendingImages();
 
-    QString likesURL();
+    QString likesUrl();
     void setLikes(QVariantList likesList, int likesCount=-1);
+    void appendLike(QString actorId, QString actorName, QString actorUrl);
+    void removeLike(QString actorId);
+    void refreshLikesInfo(int likesListSize, int likesCount);
     void setLikesLabel(int likesCount);
 
     QString commentsURL();
     void setComments(QVariantList commentsList);
+    void appendComment(ASObject *comment);
     void setCommentsLabel(int commentsCount);
 
     QString sharesURL();
@@ -89,13 +96,19 @@ public:
 
     void setPostUnreadStatus();
     void setPostAsNew();
-    void setPostAsRead();
+    void setPostAsRead(bool informTimeline=true);
+    void setPostDeleted(QString postDeletedTime);
 
     int getHighlightType();
+    QString getActivityId();
+    QString getObjectId();
 
     void setFuzzyTimestamps();
     void syncAvatarFollowState();
 
+    bool isBeingCommented();
+    bool isNew();
+
     enum PostHightlightType
     {
         NoHighlight = -1,
@@ -144,6 +157,7 @@ public slots:
     void triggerResize();
 
     void redrawImages(QString imageUrl);
+    void onImageFailed(QString imageUrl);
 
 
 protected:
@@ -164,6 +178,7 @@ private:
     QFrame *leftColumnFrame;
     QFrame *rightColumnFrame;
 
+    QString activityId;
     QString postId;
     QString postType;
     QString postUrl;
@@ -177,6 +192,7 @@ private:
 
     bool postIsOwn;
     bool postIsUnread;
+    bool postIsDeleted;
     int highlightType;
     QString unreadPostColor;
 
@@ -222,6 +238,7 @@ private:
     QString postTitle;
     QString postImageUrl;
     bool postImageIsAnimated;
+    bool postImageFailed;
     QString postAudioUrl;
     QString postVideoUrl;
     QString postFileUrl;
@@ -232,16 +249,18 @@ private:
 
     QString postCreatedAtString;
     QString postUpdatedAtString;
+    QString postGeneratorString;
 
     int postWidth;
-    int minMaxHeight;
-
     int resizesCount;
 
     QString postLikesUrl;
+    int postLikesCount;
+    QVariantMap postLikesMap;
     QString postCommentsUrl;
     QString postSharesUrl;
 
+
     QStringList pendingImagesList;
 
     bool standalone;
