@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -37,12 +37,12 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     QFont infoFont;
     infoFont.setPointSize(infoFont.pointSize() - 1);
 
-    webfingerLabel = new QLabel();
+    webfingerLabel = new QLabel(this);
     webfingerLabel->setFont(infoFont);
     webfingerLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     webfingerLabel->setToolTip(tr("This is your Pump address"));
 
-    emailLabel = new QLabel();
+    emailLabel = new QLabel(this);
     emailLabel->setFont(infoFont);
     emailLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     emailLabel->setToolTip("<b></b>" // Make the tooltip HTML so it gets wordwrap
@@ -51,24 +51,26 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
                                 "notifications and password recovery"));
 
 
-    avatarLabel = new QLabel();
+    avatarLabel = new QLabel(this);
     avatarLabel->setPixmap(QIcon::fromTheme("user-properties",
-                                            QIcon(":/images/no-avatar.png")).pixmap(64, 64));
+                                            QIcon(":/images/no-avatar.png"))
+                           .pixmap(96, 96));
 
     changeAvatarButton = new QPushButton(QIcon::fromTheme("folder-image-people"),
-                                         tr("Change &Avatar..."));
+                                         tr("Change &Avatar..."),
+                                         this);
     connect(changeAvatarButton, SIGNAL(clicked()),
             this, SLOT(findAvatarFile()));
 
     this->avatarChanged = false;
 
 
-    fullNameLineEdit = new QLineEdit();
+    fullNameLineEdit = new QLineEdit(this);
     fullNameLineEdit->setToolTip(tr("This is your visible name"));
 
-    hometownLineEdit = new QLineEdit();
+    hometownLineEdit = new QLineEdit(this);
 
-    bioTextEdit = new QTextEdit();
+    bioTextEdit = new QTextEdit(this);
     bioTextEdit->setTabChangesFocus(true);
     bioTextEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
                                QSizePolicy::MinimumExpanding);
@@ -77,13 +79,17 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
     saveButton = new QPushButton(QIcon::fromTheme("document-save",
                                                   QIcon(":/images/button-save.png")),
-                                 tr("&Save Profile"));
-    connect(saveButton, SIGNAL(clicked()), this, SLOT(saveProfile()));
+                                 tr("&Save Profile"),
+                                 this);
+    connect(saveButton, SIGNAL(clicked()),
+            this, SLOT(saveProfile()));
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
-                                   tr("&Cancel"));
-    connect(cancelButton, SIGNAL(clicked()), this, SLOT(hide()));
+                                   tr("&Cancel"),
+                                   this);
+    connect(cancelButton, SIGNAL(clicked()),
+            this, SLOT(hide()));
 
 
     // ESC to cancel, too
@@ -165,7 +171,7 @@ void ProfileEditor::setProfileData(QString avatarUrl, QString fullName,
     QString avatarFilename = MiscHelpers::getCachedAvatarFilename(this->currentAvatarURL);
     if (QFile::exists(avatarFilename))
     {
-        this->avatarLabel->setPixmap(QPixmap(avatarFilename).scaled(64, 64,
+        this->avatarLabel->setPixmap(QPixmap(avatarFilename).scaled(96, 96,
                                                                     Qt::KeepAspectRatio,
                                                                     Qt::SmoothTransformation));
     }
@@ -226,7 +232,7 @@ void ProfileEditor::findAvatarFile()
         if (!avatarPixmap.isNull() && !newAvatarContentType.isEmpty())
         {
             this->avatarLabel->setPixmap(QPixmap(newAvatarFilename)
-                                         .scaled(64, 64,
+                                         .scaled(96, 96,
                                                  Qt::KeepAspectRatio,
                                                  Qt::SmoothTransformation));
             this->avatarChanged = true;
@@ -272,8 +278,15 @@ void ProfileEditor::sendProfileData(QString newImageUrl)
         this->avatarChanged = false; // For next time the dialog is shown
     }
 
+    QString newFullName = this->fullNameLineEdit->text().trimmed();
+    if (newFullName.isEmpty())
+    {
+        // To avoid having empty names, use the username part from the ID
+        newFullName = this->pController->currentUsername();
+    }
+
     this->pController->updateUserProfile(newImageUrl,
-                                         this->fullNameLineEdit->text().trimmed(),
+                                         newFullName,
                                          this->hometownLineEdit->text().trimmed(),
                                          this->bioTextEdit->toPlainText().trimmed());
 
