@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -36,8 +36,8 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     this->globalObj = globalObject;
-    connect(globalObj, SIGNAL(messagingModeRequested(QString,QString)),
-            this, SLOT(startMessageForContact(QString,QString)));
+    connect(globalObj, SIGNAL(messagingModeRequested(QString,QString,QString)),
+            this, SLOT(startMessageForContact(QString,QString,QString)));
     connect(globalObj, SIGNAL(postEditRequested(QString,QString,QString,QString)),
             this, SLOT(setEditingMode(QString,QString,QString,QString)));
 
@@ -48,16 +48,17 @@ Publisher::Publisher(PumpController *pumpController,
                                // after clicking "Edit" in a post
 
     this->defaultPublicPosting = false; // initialize
+    this->showCharacterCounter = false;
 
     this->setFocusPolicy(Qt::StrongFocus); // To keep the publisher from getting focus by accident
 
 
     this->audienceSelectorTo = new AudienceSelector(pController, "to", this);
-    connect(audienceSelectorTo, SIGNAL(audienceSelected(QString,QStringList)),
-            this, SLOT(updateToCcFields(QString,QStringList)));
+    connect(audienceSelectorTo, SIGNAL(audienceSelected(QString,QStringList,QStringList)),
+            this, SLOT(updateToCcFields(QString,QStringList,QStringList)));
     this->audienceSelectorCC = new AudienceSelector(pController, "cc", this);
-    connect(audienceSelectorCC, SIGNAL(audienceSelected(QString,QStringList)),
-            this, SLOT(updateToCcFields(QString,QStringList)));
+    connect(audienceSelectorCC, SIGNAL(audienceSelected(QString,QStringList,QStringList)),
+            this, SLOT(updateToCcFields(QString,QStringList,QStringList)));
 
 
     QString titleTooltip = "<b></b>" + tr("Setting a title helps make the "
@@ -74,7 +75,8 @@ Publisher::Publisher(PumpController *pumpController,
     titleLineEdit = new QLineEdit();
     titleLineEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
                                  QSizePolicy::Maximum);
-    titleLineEdit->setPlaceholderText(tr("Add a brief title for the post (recommended)"));
+    titleLineEdit->setPlaceholderText(tr("Add a brief title for the post here "
+                                         "(recommended)"));
     titleLineEdit->setFont(titleFont);
     titleLineEdit->setToolTip(titleTooltip);
 
@@ -97,7 +99,19 @@ Publisher::Publisher(PumpController *pumpController,
     selectMediaButton->hide();
 
 
-    uploadProgressBar = new QProgressBar();
+    uploadProgressBar = new QProgressBar(this);
+
+    removeMediaButton = new QPushButton(QIcon::fromTheme("edit-delete",
+                                                         QIcon(":/images/button-delete.png")),
+                                        tr("Remove"));
+    removeMediaButton->setToolTip("<b></b>"
+                                  + tr("Cancel the attachment, and go "
+                                       "back to a regular note"));
+    removeMediaButton->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                     QSizePolicy::Maximum);
+    connect(removeMediaButton, SIGNAL(clicked()),
+            this, SLOT(cancelMediaMode()));
+    removeMediaButton->hide();
 
     // Set default pixmap and "media not set" message
     this->setEmptyMediaData();
@@ -105,7 +119,8 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     // Composer
-    composerBox = new Composer(true); // forPublisher = true
+    composerBox = new Composer(this->globalObj,
+                               true); // forPublisher = true
     composerBox->setSizePolicy(QSizePolicy::Minimum,
                                QSizePolicy::Minimum);
     connect(composerBox, SIGNAL(focusReceived()),
@@ -114,6 +129,10 @@ Publisher::Publisher(PumpController *pumpController,
             this, SLOT(sendPost()));
     connect(composerBox, SIGNAL(editingCancelled()),
             this, SLOT(setMinimumMode()));
+    connect(composerBox, SIGNAL(nickInserted(QString,QString,QString)),
+            this, SLOT(addNickToRecipients(QString,QString,QString)));
+    connect(composerBox, SIGNAL(textChanged()),
+            this, SLOT(updateCharacterCounter()));
 
     // Pressing Enter in title goes to message body
     connect(titleLineEdit, SIGNAL(returnPressed()),
@@ -197,18 +216,20 @@ Publisher::Publisher(PumpController *pumpController,
     audienceLabelsFont.setPointSize(audienceLabelsFont.pointSize() - 1);
 
     // These will hold the names of the *people* selected for the To or Cc fields, if any
-    toAudienceLabel = new QLabel();
+    toAudienceLabel = new QLabel(this);
     toAudienceLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     toAudienceLabel->setFont(audienceLabelsFont);  // Normal
     toAudienceLabel->setWordWrap(true);
+    toAudienceLabel->setOpenExternalLinks(true);
     connect(toAudienceLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(showHighlightedUrl(QString)));
 
-    ccAudienceLabel = new QLabel();
+    ccAudienceLabel = new QLabel(this);
     ccAudienceLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     audienceLabelsFont.setItalic(true);
     ccAudienceLabel->setFont(audienceLabelsFont);  // Italic
     ccAudienceLabel->setWordWrap(true);
+    ccAudienceLabel->setOpenExternalLinks(true);
     connect(ccAudienceLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(showHighlightedUrl(QString)));
 
@@ -268,6 +289,12 @@ Publisher::Publisher(PumpController *pumpController,
     addMediaButton->setMenu(addMediaMenu);
 
 
+    // Character counter (optional)
+    charCounterLabel = new QLabel(this);
+    charCounterLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
+    charCounterLabel->setText("0");
+
+
     // Info label for "sending" and other status information
     statusInfoLabel = new QLabel();
     statusInfoLabel->setSizePolicy(QSizePolicy::Maximum,
@@ -313,6 +340,7 @@ Publisher::Publisher(PumpController *pumpController,
     mainLayout->addWidget(mediaInfoLabel,      1, 4, 1, 4, Qt::AlignTop);
     mainLayout->addWidget(selectMediaButton,   2, 4, 1, 2, Qt::AlignBottom | Qt::AlignLeft);
     mainLayout->addWidget(uploadProgressBar,   2, 6, 1, 2, Qt::AlignBottom | Qt::AlignRight);
+    mainLayout->addWidget(removeMediaButton,   2, 6, 1, 2, Qt::AlignBottom | Qt::AlignRight);
 
     mainLayout->addWidget(composerBox,         3, 0, 3, 8); // 3 rows, 8 columns
 
@@ -331,6 +359,9 @@ Publisher::Publisher(PumpController *pumpController,
     mainLayout->addWidget(toPublicFollowersLabel, 8, 0, 1, 1);
     mainLayout->addWidget(ccPublicFollowersLabel, 8, 1, 1, 1);
 
+    // Character counter
+    mainLayout->addWidget(charCounterLabel,       8, 3, 1, 2, Qt::AlignCenter);
+
     // The "Cancel post" button
     mainLayout->addWidget(cancelButton,        8, 7, 1, 1);
 
@@ -361,12 +392,13 @@ Publisher::~Publisher()
  * Set if "public" option for audience is checked as default
  *
  */
-void Publisher::setDefaultPublicPosting(bool defaultPublicPosts)
+void Publisher::syncFromConfig()
 {
-    this->defaultPublicPosting = defaultPublicPosts;
+    this->defaultPublicPosting = this->globalObj->getPublicPostsByDefault();
+    this->showCharacterCounter = this->globalObj->getShowCharacterCounter();
 
     // Ensure status is sync'ed
-    this->toSelectorMenu->actions().at(0)->setChecked(this->defaultPublicPosting);
+    this->toSelectorMenu->actions().first()->setChecked(this->defaultPublicPosting);
 }
 
 
@@ -528,8 +560,10 @@ void Publisher::setMediaModeWidgets()
 
     this->mediaInfoLabel->show();
     this->selectMediaButton->show();
+    this->removeMediaButton->show();
 }
 
+
 /*
  * Disable some widgets while sending a post,
  * including during media upload
@@ -551,6 +585,7 @@ void Publisher::toggleWidgetsWhileSending(bool widgetsEnabled)
         this->addMediaButton->setEnabled(widgetsEnabled);
     }
     this->selectMediaButton->setEnabled(widgetsEnabled);
+    this->removeMediaButton->setEnabled(widgetsEnabled);
 
     this->postButton->setEnabled(widgetsEnabled);
 }
@@ -580,6 +615,10 @@ void Publisher::setMinimumMode()
     this->composerBox->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     this->composerBox->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+    // Disable Ctrl+Shift+V for plaintext paste, to avoid conflict with Commenters
+    this->composerBox->setPlainPasteEnabled(false);
+
+
     // ~1 row
     int composerHeight = composerBox->getMessageLabelHeight();
     this->composerBox->setMinimumHeight(composerHeight);
@@ -651,22 +690,19 @@ void Publisher::setMinimumMode()
     this->statusInfoLabel->clear();
     statusInfoLabel->hide();
     this->addMediaButton->hide();
+
+    this->charCounterLabel->hide();
+
     this->postButton->hide();
     this->cancelButton->hide();
 
 
+
     // Clear formatting options like bold, italic and underline
     this->composerBox->setCurrentCharFormat(QTextCharFormat());
 
     // Hide "media mode" controls
-    this->pictureLabel->hide();
-    this->mediaInfoLabel->hide();
-    this->selectMediaButton->hide();
-    this->uploadProgressBar->hide();
-
-    this->setEmptyMediaData();
-
-    this->postType = "note";
+    this->cancelMediaMode();
 
     // Clear "editing mode", restore stuff
     if (editingMode)
@@ -678,7 +714,6 @@ void Publisher::setMinimumMode()
                                      "verb")); // Button text back to "Post" as usual
         this->toSelectorButton->setEnabled(true);
         this->ccSelectorButton->setEnabled(true);
-        this->addMediaButton->setEnabled(true);
     }
 
     this->fullMode = false;
@@ -708,6 +743,9 @@ void Publisher::setFullMode()
     this->composerBox->hideInfoMessage();
     this->setMaximumHeight(2048); // i.e. "unlimited"
 
+    // Re-enable ctrl+shift+v for plaintext paste (disabled to avoid conflicts)
+    this->composerBox->setPlainPasteEnabled(true);
+
     this->toSelectorButton->show();
     this->ccSelectorButton->show();
 
@@ -719,13 +757,16 @@ void Publisher::setFullMode()
 
     updatePublicFollowersLabels();
 
-    // Avoid re-enabling the picture button when re-focusing publisher, but still in picture mode...
+    // Avoid re-enabling the media button when re-focusing publisher, but still in media mode...
     if (addMediaButton->isHidden())
     {
         this->addMediaButton->setEnabled(true); // If it wasn't hidden, don't re-enable
     }
     this->addMediaButton->show();
     this->statusInfoLabel->show();
+
+    this->charCounterLabel->setVisible(globalObj->getShowCharacterCounter());
+
     this->postButton->show();
     this->cancelButton->show();
 
@@ -758,7 +799,8 @@ void Publisher::setPictureMode()
 
     selectMediaButton->setIcon(QIcon::fromTheme("folder-image"));
     selectMediaButton->setText(tr("Select Picture..."));
-    selectMediaButton->setToolTip(tr("Find the picture in your folders"));
+    selectMediaButton->setToolTip("<b></b>"
+                                  + tr("Find the picture in your folders"));
 
     pictureLabel->setToolTip(tr("Picture not set"));
 
@@ -780,7 +822,8 @@ void Publisher::setAudioMode()
 
     selectMediaButton->setIcon(QIcon::fromTheme("folder-sound"));
     selectMediaButton->setText(tr("Select Audio File..."));
-    selectMediaButton->setToolTip(tr("Find the audio file in your folders"));
+    selectMediaButton->setToolTip("<b></b>"
+                                  + tr("Find the audio file in your folders"));
 
     pictureLabel->setToolTip(tr("Audio file not set"));
 
@@ -803,7 +846,8 @@ void Publisher::setVideoMode()
 
     selectMediaButton->setIcon(QIcon::fromTheme("folder-video"));
     selectMediaButton->setText(tr("Select Video..."));
-    selectMediaButton->setToolTip(tr("Find the video in your folders"));
+    selectMediaButton->setToolTip("<b></b>"
+                                  + tr("Find the video in your folders"));
 
     pictureLabel->setToolTip(tr("Video not set"));
 
@@ -825,7 +869,8 @@ void Publisher::setFileMode()
 
     selectMediaButton->setIcon(QIcon::fromTheme("folder"));
     selectMediaButton->setText(tr("Select File..."));
-    selectMediaButton->setToolTip(tr("Find the file in your folders"));
+    selectMediaButton->setToolTip("<b></b>"
+                                  + tr("Find the file in your folders"));
 
     pictureLabel->setToolTip(tr("File not set"));
 
@@ -833,6 +878,26 @@ void Publisher::setFileMode()
 }
 
 
+/*
+ * Remove the attachment from the publisher
+ *
+ */
+void Publisher::cancelMediaMode()
+{
+    this->addMediaButton->setEnabled(true);
+
+    this->pictureLabel->hide();
+    this->mediaInfoLabel->hide();
+    this->selectMediaButton->hide();
+    this->removeMediaButton->hide();
+    this->uploadProgressBar->hide();
+
+    this->setEmptyMediaData();
+
+    this->postType = "note";
+}
+
+
 
 /*
  * Set Publiser to edit mode, after user clicks on "Edit" in a post
@@ -878,7 +943,7 @@ void Publisher::setEditingMode(QString postId, QString postType,
 }
 
 
-void Publisher::startMessageForContact(QString name, QString id)
+void Publisher::startMessageForContact(QString id, QString name, QString url)
 {
     if (name.trimmed().isEmpty()) // Ensure "name" has some text in it
     {
@@ -906,7 +971,8 @@ void Publisher::startMessageForContact(QString name, QString id)
     // Add user name/ID to the "To" field...
     this->audienceSelectorTo->copyToSelected(QIcon::fromTheme("user-identity",
                                                               QIcon(":/images/no-avatar.png")),
-                                             QString("%1 <%2>").arg(name).arg(id));
+                                             QString("%1 <%2>").arg(name).arg(id),
+                                             url);
     this->audienceSelectorTo->setAudience();
 
 
@@ -914,6 +980,21 @@ void Publisher::startMessageForContact(QString name, QString id)
     this->titleLineEdit->setText(name + ":");
 }
 
+/*
+ * Add name + id to selected recipients when auto-completing a nick
+ *
+ * 'name' can always be expected to have a value
+ *
+ */
+void Publisher::addNickToRecipients(QString id, QString name, QString url)
+{
+    this->audienceSelectorTo->copyToSelected(QIcon::fromTheme("user-identity",
+                                                              QIcon(":/images/no-avatar.png")),
+                                             QString("%1 <%2>").arg(name).arg(id),
+                                             url);
+    this->audienceSelectorTo->setAudience();
+}
+
 
 /*
  * After the post is confirmed to have been received by the server
@@ -939,7 +1020,16 @@ void Publisher::onPublishingFailed()
 {
     qDebug() << "Posting failed, re-enabling Publisher";
     this->statusInfoLabel->setText(tr("Posting failed.\n\nTry again."));
+
     this->toggleWidgetsWhileSending(true);
+    this->uploadProgressBar->hide();
+
+    // In media mode, show the "remove" button again (hidden during upload)
+    if (this->postType != "note")
+    {
+        this->removeMediaButton->show();
+    }
+
     this->composerBox->setFocus();
 }
 
@@ -994,7 +1084,8 @@ void Publisher::setCCFollowers(bool activated)
  *
  */
 void Publisher::updateToCcFields(QString selectorType,
-                                 QStringList contactsList)
+                                 QStringList contactsList,
+                                 QStringList urlsList)
 {
     qDebug() << "Publisher::updateToCcFields()" << selectorType << contactsList;
 
@@ -1004,22 +1095,42 @@ void Publisher::updateToCcFields(QString selectorType,
     QString addressesString;
     QStringList addressesStringList;
 
+    QString contactName;
+    QString contactId;
+    QString contactUrl;
+
+    int urlCounter = 0;
+    int urlsListLast = urlsList.size() - 1;
     foreach (QString contactString, contactsList)
     {
         contactRE.indexIn(contactString);
 
-        // FIXME: make links to each profile here -- WIP
-        QString contactAddress = contactRE.cap(2).trimmed();
-        //QString contactUrl = contactAddress.split("@").last() + "/" + ...;
+        contactName = contactRE.cap(1).trimmed();
+        contactId = contactRE.cap(2).trimmed();
+        if (contactName.isEmpty())
+        {
+            contactName = contactId;
+        }
 
-        addressesString.append("<a href=\"" + contactAddress + "\">"
-                               + contactRE.cap(1).trimmed()
-                               + "</a>");
-        addressesString.append(", ");
+        contactUrl.clear();
+        if (urlCounter <= urlsListLast) // Ensure stringlist position is valid
+        {                               // Works even if the list is empty: 0 <= -1
+            contactUrl = urlsList.at(urlCounter);
+        }
 
-        addressesStringList.append(contactAddress);
+        // Append to the visible names string to be displayed under the composer
+        addressesString.append("<a href=\"" + contactUrl + "\">"
+                               + contactName + "</a>");
+
+        if (urlCounter < urlsListLast) // Not in the last item yet
+        {
+            addressesString.append(", ");
+            ++urlCounter;
+        }
+
+        // Add also to the simple ID list for getAudienceMap()
+        addressesStringList.append(contactId);
     }
-    addressesString.remove(-2, 2); // remove ", " at the end
 
 
     if (selectorType == "to")
@@ -1251,6 +1362,9 @@ void Publisher::sendPost()
                 // This will be automatically disconnected when
                 // the networkReply is automatically deleted!
 
+                // The "remove" button uses the same space as the progress bar
+                removeMediaButton->hide();
+
                 uploadProgressBar->setValue(0);
                 uploadProgressBar->show();
             }
@@ -1369,7 +1483,8 @@ void Publisher::findMediaFile()
         }
         else if (!mediaContentType.isEmpty())
         {
-            this->pictureLabel->setToolTip(filename);
+            this->pictureLabel->setToolTip("<b></b>" // wordwrapped
+                                           + filename);
             this->mediaFilename = filename;
 
             QString metaDataString;
@@ -1402,6 +1517,19 @@ void Publisher::findMediaFile()
                                          mediaContentType,
                                          MiscHelpers::fileSizeString(filename))
                                     + metaDataString);
+
+            // If there's no title, set one from the filename
+            if (this->titleLineEdit->text().trimmed().isEmpty())
+            {
+                // But only if configured to do so
+                if (this->globalObj->getUseFilenameAsTitle())
+                {
+                    QString titleFromFilename = fileInfo.fileName(); // .baseName() ?
+                    titleFromFilename.replace("_", " ");
+                    titleFromFilename.replace(".", " ");
+                    this->titleLineEdit->setText(titleFromFilename);
+                }
+            }
         }
         else
         {
@@ -1425,6 +1553,13 @@ void Publisher::updateProgressBar(qint64 sent, qint64 total)
     this->uploadProgressBar->setValue(sent);
 
     this->uploadProgressBar->setToolTip(tr("%1 KiB of %2 KiB uploaded")
-                                         .arg(sent / 1024)
+                                        .arg(sent / 1024)
                                         .arg(total / 1024));
 }
+
+
+void Publisher::updateCharacterCounter()
+{
+    int charCount = composerBox->textCursor().document()->characterCount() - 1;
+    this->charCounterLabel->setText(QString("%1").arg(charCount));
+}
