@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ public:
                        QWidget *parent = 0);
     ~Publisher();
 
-    void setDefaultPublicPosting(bool defaultPublicPosts);
+    void syncFromConfig();
     void setEmptyMediaData();
     void updatePublicFollowersLabels();
 
@@ -75,12 +75,14 @@ public slots:
     void setVideoMode();
     void setFileMode();
 
+    void cancelMediaMode();
+
     void setEditingMode(QString postId, QString postType,
                         QString postTitle, QString postText);
 
 
-    void startMessageForContact(QString name,
-                                QString id);
+    void startMessageForContact(QString id, QString name, QString url);
+    void addNickToRecipients(QString id, QString name, QString url);
 
     void onPublishingOk();
     void onPublishingFailed();
@@ -90,8 +92,8 @@ public slots:
     void setCCPublic(bool activated);
     void setCCFollowers(bool activated);
 
-    void updateToCcFields(QString selectorType,
-                          QStringList contactsList);
+    void updateToCcFields(QString selectorType, QStringList contactsList,
+                          QStringList urlsList);
 
     void updateListsMenus(QVariantList listsList);
     void updateToListsFields(QAction *listAction);
@@ -102,9 +104,10 @@ public slots:
     void sendPost();
 
     void findMediaFile();
-
     void updateProgressBar(qint64 sent, qint64 total);
 
+    void updateCharacterCounter();
+
 
 private:
     QGridLayout *mainLayout;
@@ -114,6 +117,7 @@ private:
     QLineEdit *titleLineEdit;
     QLabel *mediaInfoLabel;
     QPushButton *selectMediaButton;
+    QPushButton *removeMediaButton;
     QLabel *pictureLabel;
     QProgressBar *uploadProgressBar;
 
@@ -154,9 +158,6 @@ private:
     QLineEdit *groupIdLineEdit;
 #endif
 
-    bool defaultPublicPosting;
-    bool onlyToFollowers;
-
     QPushButton *addMediaButton;
     QMenu *addMediaMenu;
     QAction *addMediaImageAction;
@@ -164,12 +165,19 @@ private:
     QAction *addMediaVideoAction;
     QAction *addMediaFileAction;
 
+    QLabel *charCounterLabel;
+
     QLabel *statusInfoLabel;
 
     QPushButton *postButton;
     QPushButton *cancelButton;
 
 
+    bool defaultPublicPosting;
+    bool showCharacterCounter;
+
+    bool onlyToFollowers;
+
     QString mediaFilename;
     QString mediaContentType;
     QString lastUsedDirectory;
