@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@
 
 #include "mischelpers.h"
 #include "asperson.h"
-
+#include "asobject.h"
 
 
 class PumpController : public QObject
@@ -136,8 +136,6 @@ public:
     void setPostsPerPageMain(int ppp);
     void setPostsPerPageOther(int ppp);
 
-    void setUpdatesToTimelineBlocked(bool blocked);
-
 
     void setNewUserId(QString userId);
     void setUserCredentials(QString userId);
@@ -146,6 +144,7 @@ public:
     QString currentFollowersUrl();
     int currentFollowersCount();
     int currentFollowingCount();
+    bool currentlyAuthorized();
 
     void getUserProfile(QString userId);
     void updateUserProfile(QString avatarUrl, QString fullName,
@@ -158,6 +157,7 @@ public:
     QNetworkReply *getMedia(QString mediaUrl);
     void notifyAvatarStored(QString avatarUrl, QString avatarFilename);
     void notifyImageStored(QString imageUrl);
+    void notifyImageFailed(QString imageUrl);
 
     void getContactList(QString listType, int offset=0);
     bool userInFollowing(QString contactId);
@@ -175,19 +175,14 @@ public:
     void joinGroup(QString id);
     void leaveGroup(QString id);
 
-    void getMainTimeline(int timelineOffset);
-    void getDirectTimeline(int timelineOffset);
-    void getActivityTimeline(int timelineOffset);
-    void getFavoritesTimeline(int timelineOffset);
-
-    void getTimeline(int timelineType, QString url);
-
     void getPostLikes(QString postLikesUrl);
     void getPostComments(QString postCommentsUrl);
     void getPostShares(QString postSharesUrl);
 
-    void getMinorFeed(requestTypes feedType, int offset = 0);
-    void getMinorFeedProper(QString url = "");
+    void getFeed(requestTypes feedType, int itemCount,
+                 QString url = "", int feedOffset = 0);
+    static QStringList getFeedNameAndPath(int feedType);
+    QString getFeedApiUrl(int feedType);
 
     QNetworkRequest prepareRequest(QString url,
                                    QOAuth::HttpMethod method,
@@ -202,17 +197,29 @@ public:
 
     QList<QVariantList> processAudience(QMap<QString,QString> audienceMap);
 
+    bool urlIsInOurHost(QString url);
+    void addCommentUrlToSeenList(QString id, QString url);
+    QString commentsUrlForPost(QString id);
+
     void showTransientMessage(QString message);
 
-    void showStatusMessageAndLogIt(QString message);
+    void showStatusMessageAndLogIt(QString message, QString url="");
+    void showObjectSnippetAndLogIt(QString message,
+                                   QVariantMap jsonMap,
+                                   QString messageWhenTitled="");
 
+    void setIgnoreSslErrors(bool state);
+    void setIgnoreSslInImages(bool state);
+
+    void updatePostsEverSeen(QVariantMap postMap);
+    QVariantMap getPostsEverSeen();
 
 
 signals:
     void openingAuthorizeURL(QUrl url);
     void authorizationFailed(QString errorTitle, QString errorMessage);
     void authorizationStatusChanged(bool authorized);
-    void initializationComplete();
+    void initializationCompleted();
 
     void profileReceived(QString avatarURL, QString fullName,
                          QString hometown, QString bio,
@@ -246,14 +253,18 @@ signals:
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
 
     void minorFeedMainReceived(QVariantList activitiesList,
-                               QString previousLink, QString nextLink);
+                               QString previousLink, QString nextLink,
+                               int totalItemCount);
     void minorFeedDirectReceived(QVariantList activitiesList,
-                                 QString previousLink, QString nextLink);
+                                 QString previousLink, QString nextLink,
+                                 int totalItemCount);
     void minorFeedActivityReceived(QVariantList activitiesList,
-                                   QString previousLink, QString nextLink);
+                                   QString previousLink, QString nextLink,
+                                   int totalItemCount);
 
-    void avatarPictureReceived(QByteArray pictureData, QUrl pictureURL);
-    void imageReceived(QByteArray pictureData, QUrl pictureURL);
+    void avatarPictureReceived(QByteArray pictureData, QString pictureUrl);
+    void imageReceived(QByteArray pictureData, QString pictureUrl);
+    void imageFailed(QString imageUrl);
     void downloadCompleted(QString fileUrl);
     void downloadFailed(QString fileUrl);
     void avatarStored(QString avatarUrl, QString avatarFilename);
@@ -265,6 +276,8 @@ signals:
     void commentPosted();
     void commentPostingFailed();
 
+    void userDidSomething();
+
     void avatarUploaded(QString url);
 
     void showNotification(QString message);
@@ -342,6 +355,8 @@ private:
     int totalReceivedFollowers;
     int totalReceivedFollowing;
 
+    QVariantMap postsEverSeen;
+
     QTimer *initialDataTimer;
     int initialDataStep;
     int initialDataAttempts;
@@ -360,7 +375,6 @@ private:
 
     int postsPerPageMain;
     int postsPerPageOther;
-    bool updatesToTimelineBlocked;
 
 
     // For multi-step operations in posts
@@ -372,6 +386,9 @@ private:
     // Avatars / Images queue
     QStringList pendingAvatarsList;
     QStringList pendingImagesList;
+
+    bool ignoreSslErrors;
+    bool ignoreSslInImages;
 };
 
 #endif // PUMPCONTROLLER_H
