@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ class TimeLine : public QWidget
     Q_OBJECT
 
 public:
-    TimeLine(int timelineType,
+    TimeLine(PumpController::requestTypes timelineType,
              PumpController *pumpController,
              GlobalObject *globalObject,
              FilterChecker *filterChecker,
@@ -53,44 +53,38 @@ public:
     ~TimeLine();
 
     void clearTimeLineContents();
-    void requestTimelinePage();
+    void removeOldPosts(int minimumToKeep);
+    void insertSeparator(int position);
+
     int getCurrentPage();
     int getTotalPages();
     void updateCurrentPageNumber();
 
-    void setMinMaxHeightForPosts(int newMinMaxHeightForPosts);
-    void resizePosts();
+    void resizePosts(QList<Post *> postsToResize, bool resizeAll=false);
 
     void markPostsAsRead();
 
     void updateFuzzyTimestamps();
 
+    bool commentingOnAnyPost();
+    void notifyBlockedUpdates();
 
-
-    enum TimelineTypes
-    {
-        TimelineTypeMain,
-        TimelineTypeDirect,
-        TimelineTypeActivity,
-        TimelineTypeFavorites
-    };
-
+    QList<Post *> getPostsInTimeline();
 
 
 signals:
-    void getPreviousPage();
-    void getNextPage();
-
     void scrollTo(QAbstractSlider::SliderAction sliderAction);
 
-    void timelineRendered(int timelineType,
+    void timelineRendered(PumpController::requestTypes timelineType,
                           int newPostCount,
                           int highlightedPostsCount,
-                          int totalItemsCount);
-    void unreadPostsCountChanged(int timelineType,
+                          int deletedPostsCount,
+                          int filteredPostsCount,
+                          int pendingForNextUpdate);
+    void unreadPostsCountChanged(PumpController::requestTypes timelineType,
                                  int newPostCount,
                                  int highlightedCount,
-                                 int totalItemsCount);
+                                 int fullTimelinePostCount);
 
     void commentingOnPost(QWidget *commenterWidget);
 
@@ -100,6 +94,16 @@ public slots:
                              QString previousLink, QString nextLink,
                              int totalItems);
 
+    void updatePostsFromMinorFeed(ASObject *object);
+    void addLikesFromMinorFeed(QString objectId, QString objectType,
+                               QString actorId, QString actorName,
+                               QString actorUrl);
+    void removeLikesFromMinorFeed(QString objectId, QString objectType,
+                                  QString actorId);
+    void addReplyFromMinorFeed(ASObject *object);
+    void setPostsDeletedFromMinorFeed(ASObject *object);
+
+
     void setLikesInPost(QVariantList likesList, QString originatingPostURL);
     void setCommentsInPost(QVariantList commentsList, QString originatingPostURL);
     //void setSharesInPost(...)
@@ -139,8 +143,23 @@ private:
     QPushButton *previousPageButton;
     QPushButton *nextPageButton;
 
+    QPushButton *getNewPendingButton;
+
+    QFrame *separatorFrame;
+
+
     QString previousPageLink;
     QString nextPageLink;
+    int fullTimelinePostCount;
+    int pendingToReceiveNextTime;
+    bool firstLoad;
+    bool gettingNew;
+    bool wasOnFirstPage;
+
+    int timelineOffset;
+    int postsPerPage;
+    int unreadPostsCount;
+    int highlightedPostsCount;
 
     QAction *scrollUpAction;
     QAction *scrollDownAction;
@@ -154,20 +173,14 @@ private:
 
     PageSelector *pageSelector;
 
-    int timelineType;
-
-    int timelineOffset;
-    int postsPerPage;
-    int unreadPostsCount;
-    int newHighlightedPostsCount;
-    int totalItemsCount;
-
-    int minMaxHeightForPosts;
+    PumpController::requestTypes timelineType;
+    bool favoritesTimeline;
 
 
     QString previousNewestPostId;
 
     QList<Post *> postsInTimeline;
+    QStringList objectsIdList;
 };
 
 #endif // TIMELINE_H
